# allure-testops-client
Branch **HEAD**  Commit **623f6ed302ba4b651cf9040faca4635af2d93b7c**

The `src.client.generated` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 25.4.1
- Package version: 1.0.0
- Generator version: 7.19.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 2.1.0, < 3.0.0
* python-dateutil >= 2.8.2
* aiohttp >= 3.8.4
* aiohttp-retry >= 2.8.3
* pydantic >= 2
* typing-extensions >= 4.7.1

## Getting Started

In your own code, to use this library to connect and interact with allure-testops-client,
you can run the following:

```python

import src.client.generated
from src.client.generated.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = src.client.generated.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
async with src.client.generated.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = src.client.generated.CustomFieldControllerApi(api_client)
    id = [56] # List[int] | 

    try:
        # Count custom fields usage in projects
        api_response = await api_instance.count_usage(id)
        print("The response of CustomFieldControllerApi->count_usage:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CustomFieldControllerApi->count_usage: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CustomFieldControllerApi* | [**count_usage**](src/client/generated/docs/CustomFieldControllerApi.md#count_usage) | **GET** /api/cf/count-usage | Count custom fields usage in projects
*CustomFieldControllerApi* | [**create52**](src/client/generated/docs/CustomFieldControllerApi.md#create52) | **POST** /api/cf | 
*CustomFieldControllerApi* | [**delete43**](src/client/generated/docs/CustomFieldControllerApi.md#delete43) | **DELETE** /api/cf/{id} | 
*CustomFieldControllerApi* | [**find_by_project**](src/client/generated/docs/CustomFieldControllerApi.md#find_by_project) | **GET** /api/cf | Deprecated. Use GET /api/project/{projectId}/cf instead
*CustomFieldControllerApi* | [**find_one37**](src/client/generated/docs/CustomFieldControllerApi.md#find_one37) | **GET** /api/cf/{id} | 
*CustomFieldControllerApi* | [**merge4**](src/client/generated/docs/CustomFieldControllerApi.md#merge4) | **POST** /api/cf/merge | 
*CustomFieldControllerApi* | [**patch48**](src/client/generated/docs/CustomFieldControllerApi.md#patch48) | **PATCH** /api/cf/{id} | 
*CustomFieldControllerApi* | [**set_archived**](src/client/generated/docs/CustomFieldControllerApi.md#set_archived) | **POST** /api/cf/{id}/archived | Soft delete custom field
*CustomFieldControllerApi* | [**suggest22**](src/client/generated/docs/CustomFieldControllerApi.md#suggest22) | **GET** /api/cf/suggest | 
*CustomFieldProjectControllerApi* | [**add2**](src/client/generated/docs/CustomFieldProjectControllerApi.md#add2) | **POST** /api/cfproject/add | Add custom field to projects
*CustomFieldProjectControllerApi* | [**add_to_project**](src/client/generated/docs/CustomFieldProjectControllerApi.md#add_to_project) | **POST** /api/cfproject/add-to-project | Add custom fields to project
*CustomFieldProjectControllerApi* | [**cf_delta1**](src/client/generated/docs/CustomFieldProjectControllerApi.md#cf_delta1) | **POST** /api/cfproject/delta | Find missing custom fields
*CustomFieldProjectControllerApi* | [**find_one45**](src/client/generated/docs/CustomFieldProjectControllerApi.md#find_one45) | **GET** /api/cfproject | 
*CustomFieldProjectControllerApi* | [**find_projects_by_custom_field**](src/client/generated/docs/CustomFieldProjectControllerApi.md#find_projects_by_custom_field) | **GET** /api/cfproject/in-projects | Find projects that use specified custom field
*CustomFieldProjectControllerApi* | [**remove4**](src/client/generated/docs/CustomFieldProjectControllerApi.md#remove4) | **DELETE** /api/cfproject/remove | Remove custom field from project
*CustomFieldProjectControllerApi* | [**set_default**](src/client/generated/docs/CustomFieldProjectControllerApi.md#set_default) | **POST** /api/cfproject/default | Deprecated. Use PATCH /api/project/{projectId}/cf/{cfId} instead
*CustomFieldProjectControllerApi* | [**set_required**](src/client/generated/docs/CustomFieldProjectControllerApi.md#set_required) | **POST** /api/cfproject/required | Deprecated. Use PATCH /api/project/{projectId}/cf/{cfId} instead
*CustomFieldProjectControllerV2Api* | [**find_by_project1**](src/client/generated/docs/CustomFieldProjectControllerV2Api.md#find_by_project1) | **GET** /api/project/{projectId}/cf | Find custom fields used in specified project
*CustomFieldProjectControllerV2Api* | [**patch24**](src/client/generated/docs/CustomFieldProjectControllerV2Api.md#patch24) | **PATCH** /api/project/{projectId}/cf/{cfId} | 
*CustomFieldSchemaControllerApi* | [**count_mappings**](src/client/generated/docs/CustomFieldSchemaControllerApi.md#count_mappings) | **GET** /api/cfschema/count-mappings | Count custom fields mappings
*CustomFieldSchemaControllerApi* | [**create51**](src/client/generated/docs/CustomFieldSchemaControllerApi.md#create51) | **POST** /api/cfschema | Create a new custom field schema
*CustomFieldSchemaControllerApi* | [**delete42**](src/client/generated/docs/CustomFieldSchemaControllerApi.md#delete42) | **DELETE** /api/cfschema/{id} | Delete custom field schema by id
*CustomFieldSchemaControllerApi* | [**find_all45**](src/client/generated/docs/CustomFieldSchemaControllerApi.md#find_all45) | **GET** /api/cfschema | Find all custom field schemas for specified project and custom field
*CustomFieldSchemaControllerApi* | [**find_one36**](src/client/generated/docs/CustomFieldSchemaControllerApi.md#find_one36) | **GET** /api/cfschema/{id} | Find custom field schema by id
*CustomFieldSchemaControllerApi* | [**patch47**](src/client/generated/docs/CustomFieldSchemaControllerApi.md#patch47) | **PATCH** /api/cfschema/{id} | Patch custom field schema
*CustomFieldValueControllerApi* | [**create50**](src/client/generated/docs/CustomFieldValueControllerApi.md#create50) | **POST** /api/cfv | Deprecated. Use POST /api/project/{projectId}/cfv instead
*CustomFieldValueControllerApi* | [**delete41**](src/client/generated/docs/CustomFieldValueControllerApi.md#delete41) | **DELETE** /api/cfv/{id} | Delete custom field value by id
*CustomFieldValueControllerApi* | [**find_all44**](src/client/generated/docs/CustomFieldValueControllerApi.md#find_all44) | **GET** /api/cfv | Find all custom field values
*CustomFieldValueControllerApi* | [**find_one35**](src/client/generated/docs/CustomFieldValueControllerApi.md#find_one35) | **GET** /api/cfv/{id} | Find custom field value by id
*CustomFieldValueControllerApi* | [**merge_project_fields_to_existing_global_value**](src/client/generated/docs/CustomFieldValueControllerApi.md#merge_project_fields_to_existing_global_value) | **POST** /api/cfv/merge-to/{toCfvId} | Merge project custom field values into existing global
*CustomFieldValueControllerApi* | [**merge_project_fields_to_new_global_value**](src/client/generated/docs/CustomFieldValueControllerApi.md#merge_project_fields_to_new_global_value) | **POST** /api/cfv/merge | Merge project custom field values into new global
*CustomFieldValueControllerApi* | [**patch46**](src/client/generated/docs/CustomFieldValueControllerApi.md#patch46) | **PATCH** /api/cfv/{id} | Patch custom field value
*CustomFieldValueControllerApi* | [**rename_custom_field_value**](src/client/generated/docs/CustomFieldValueControllerApi.md#rename_custom_field_value) | **POST** /api/cfv/{id}/rename | Deprecated. Use PUT /api/project/{projectId}/cfv/{cvfId}/name instead
*CustomFieldValueControllerApi* | [**suggest21**](src/client/generated/docs/CustomFieldValueControllerApi.md#suggest21) | **GET** /api/cfv/suggest | Suggest custom field values
*CustomFieldValueControllerApi* | [**suggest_v2**](src/client/generated/docs/CustomFieldValueControllerApi.md#suggest_v2) | **GET** /api/cfv/suggest/{projectId} | Suggest custom field values
*CustomFieldValueProjectControllerApi* | [**create26**](src/client/generated/docs/CustomFieldValueProjectControllerApi.md#create26) | **POST** /api/project/{projectId}/cfv | Create a new custom field value for specified project
*CustomFieldValueProjectControllerApi* | [**delete47**](src/client/generated/docs/CustomFieldValueProjectControllerApi.md#delete47) | **DELETE** /api/project/{projectId}/cfv/{id} | Delete specified custom field value for specified project
*CustomFieldValueProjectControllerApi* | [**find_all22**](src/client/generated/docs/CustomFieldValueProjectControllerApi.md#find_all22) | **GET** /api/project/{projectId}/cfv | Find all custom field values for specified project
*CustomFieldValueProjectControllerApi* | [**merge_custom_fields_to_existing_record**](src/client/generated/docs/CustomFieldValueProjectControllerApi.md#merge_custom_fields_to_existing_record) | **POST** /api/project/{projectId}/cfv/merge-to/{toCfvId} | Merge custom field values to existing record by id
*CustomFieldValueProjectControllerApi* | [**merge_custom_fields_to_new_record**](src/client/generated/docs/CustomFieldValueProjectControllerApi.md#merge_custom_fields_to_new_record) | **POST** /api/project/{projectId}/cfv/merge | Merge custom field values to new record
*CustomFieldValueProjectControllerApi* | [**patch23**](src/client/generated/docs/CustomFieldValueProjectControllerApi.md#patch23) | **PATCH** /api/project/{projectId}/cfv/{cfvId} | Patch specified custom field value, test results won&#39;t be affected
*DefectControllerApi* | [**create45**](src/client/generated/docs/DefectControllerApi.md#create45) | **POST** /api/defect | 
*DefectControllerApi* | [**create_issue**](src/client/generated/docs/DefectControllerApi.md#create_issue) | **POST** /api/defect/{id}/createissue | 
*DefectControllerApi* | [**delete37**](src/client/generated/docs/DefectControllerApi.md#delete37) | **DELETE** /api/defect/{id} | 
*DefectControllerApi* | [**find_all_by_project_id**](src/client/generated/docs/DefectControllerApi.md#find_all_by_project_id) | **GET** /api/defect | 
*DefectControllerApi* | [**find_by_id1**](src/client/generated/docs/DefectControllerApi.md#find_by_id1) | **GET** /api/defect/{id} | 
*DefectControllerApi* | [**get_launches**](src/client/generated/docs/DefectControllerApi.md#get_launches) | **GET** /api/defect/{id}/launch | 
*DefectControllerApi* | [**get_matchers**](src/client/generated/docs/DefectControllerApi.md#get_matchers) | **GET** /api/defect/{id}/matcher | 
*DefectControllerApi* | [**get_test_cases2**](src/client/generated/docs/DefectControllerApi.md#get_test_cases2) | **GET** /api/defect/{id}/testcase | 
*DefectControllerApi* | [**get_test_results**](src/client/generated/docs/DefectControllerApi.md#get_test_results) | **GET** /api/defect/{id}/testresult | 
*DefectControllerApi* | [**link_issue**](src/client/generated/docs/DefectControllerApi.md#link_issue) | **POST** /api/defect/{id}/issue | 
*DefectControllerApi* | [**patch42**](src/client/generated/docs/DefectControllerApi.md#patch42) | **PATCH** /api/defect/{id} | 
*DefectControllerApi* | [**suggest20**](src/client/generated/docs/DefectControllerApi.md#suggest20) | **GET** /api/defect/suggest | 
*DefectControllerApi* | [**unlink_issue**](src/client/generated/docs/DefectControllerApi.md#unlink_issue) | **DELETE** /api/defect/{id}/issue | 
*DefectMatcherControllerApi* | [**create46**](src/client/generated/docs/DefectMatcherControllerApi.md#create46) | **POST** /api/defect/matcher | 
*DefectMatcherControllerApi* | [**delete38**](src/client/generated/docs/DefectMatcherControllerApi.md#delete38) | **DELETE** /api/defect/matcher/{id} | 
*DefectMatcherControllerApi* | [**patch43**](src/client/generated/docs/DefectMatcherControllerApi.md#patch43) | **PATCH** /api/defect/matcher/{id} | 
*IntegrationControllerApi* | [**create37**](src/client/generated/docs/IntegrationControllerApi.md#create37) | **POST** /api/integration | 
*IntegrationControllerApi* | [**create_project_integration**](src/client/generated/docs/IntegrationControllerApi.md#create_project_integration) | **POST** /api/integration/project | 
*IntegrationControllerApi* | [**delete_by_id3**](src/client/generated/docs/IntegrationControllerApi.md#delete_by_id3) | **DELETE** /api/integration/{id} | 
*IntegrationControllerApi* | [**delete_project_integration**](src/client/generated/docs/IntegrationControllerApi.md#delete_project_integration) | **DELETE** /api/integration/{integrationId}/project/{projectId} | 
*IntegrationControllerApi* | [**find_one_by_id**](src/client/generated/docs/IntegrationControllerApi.md#find_one_by_id) | **GET** /api/integration/{id} | 
*IntegrationControllerApi* | [**find_project_integration_by_id**](src/client/generated/docs/IntegrationControllerApi.md#find_project_integration_by_id) | **GET** /api/integration/{integrationId}/project/{projectId} | 
*IntegrationControllerApi* | [**get_available_integrations**](src/client/generated/docs/IntegrationControllerApi.md#get_available_integrations) | **GET** /api/integration/available | 
*IntegrationControllerApi* | [**get_global_fields**](src/client/generated/docs/IntegrationControllerApi.md#get_global_fields) | **GET** /api/integration/globalfields | 
*IntegrationControllerApi* | [**get_integration_projects**](src/client/generated/docs/IntegrationControllerApi.md#get_integration_projects) | **GET** /api/integration/{id}/project | 
*IntegrationControllerApi* | [**get_integrations**](src/client/generated/docs/IntegrationControllerApi.md#get_integrations) | **GET** /api/integration | 
*IntegrationControllerApi* | [**get_project_available_integrations**](src/client/generated/docs/IntegrationControllerApi.md#get_project_available_integrations) | **GET** /api/integration/project/{projectId}/available | 
*IntegrationControllerApi* | [**get_project_integration_fields**](src/client/generated/docs/IntegrationControllerApi.md#get_project_integration_fields) | **GET** /api/integration/projectfields | 
*IntegrationControllerApi* | [**get_project_integrations**](src/client/generated/docs/IntegrationControllerApi.md#get_project_integrations) | **GET** /api/integration/project/{projectId} | 
*IntegrationControllerApi* | [**patch34**](src/client/generated/docs/IntegrationControllerApi.md#patch34) | **PATCH** /api/integration/{id} | 
*IntegrationControllerApi* | [**patch_project_integration**](src/client/generated/docs/IntegrationControllerApi.md#patch_project_integration) | **PATCH** /api/integration/{integrationId}/project/{projectId} | 
*IntegrationControllerApi* | [**suggest15**](src/client/generated/docs/IntegrationControllerApi.md#suggest15) | **GET** /api/integration/suggest | Suggest integrations
*IntegrationControllerApi* | [**validate1**](src/client/generated/docs/IntegrationControllerApi.md#validate1) | **POST** /api/integration/validate | 
*IntegrationControllerApi* | [**validate2**](src/client/generated/docs/IntegrationControllerApi.md#validate2) | **POST** /api/integration/project/validate | 
*LaunchControllerApi* | [**add_test_cases**](src/client/generated/docs/LaunchControllerApi.md#add_test_cases) | **POST** /api/launch/{id}/testcase/add | Add test cases to launch
*LaunchControllerApi* | [**add_test_plan**](src/client/generated/docs/LaunchControllerApi.md#add_test_plan) | **POST** /api/launch/{id}/testplan/add | Add test plan to launch
*LaunchControllerApi* | [**apply_defect_matchers**](src/client/generated/docs/LaunchControllerApi.md#apply_defect_matchers) | **POST** /api/launch/{id}/defect/apply | Apply defect matchers to launch
*LaunchControllerApi* | [**close**](src/client/generated/docs/LaunchControllerApi.md#close) | **POST** /api/launch/{id}/close | Close launch
*LaunchControllerApi* | [**copy_launch**](src/client/generated/docs/LaunchControllerApi.md#copy_launch) | **POST** /api/launch/{id}/copy | Copy launch
*LaunchControllerApi* | [**create31**](src/client/generated/docs/LaunchControllerApi.md#create31) | **POST** /api/launch | Create a new launch
*LaunchControllerApi* | [**create33**](src/client/generated/docs/LaunchControllerApi.md#create33) | **POST** /api/launch/new | Create a new launch via event
*LaunchControllerApi* | [**delete27**](src/client/generated/docs/LaunchControllerApi.md#delete27) | **DELETE** /api/launch/{id} | Delete launch by id
*LaunchControllerApi* | [**find_all29**](src/client/generated/docs/LaunchControllerApi.md#find_all29) | **GET** /api/launch | Find all launches preview
*LaunchControllerApi* | [**find_one23**](src/client/generated/docs/LaunchControllerApi.md#find_one23) | **GET** /api/launch/{id} | Find launch by id
*LaunchControllerApi* | [**get_assignees**](src/client/generated/docs/LaunchControllerApi.md#get_assignees) | **GET** /api/launch/{id}/assignees | Get launch assignees
*LaunchControllerApi* | [**get_defects2**](src/client/generated/docs/LaunchControllerApi.md#get_defects2) | **GET** /api/launch/{id}/defect | Get launch defects
*LaunchControllerApi* | [**get_duration**](src/client/generated/docs/LaunchControllerApi.md#get_duration) | **GET** /api/launch/{id}/duration | Get launch duration
*LaunchControllerApi* | [**get_environment**](src/client/generated/docs/LaunchControllerApi.md#get_environment) | **GET** /api/launch/{id}/env | Get launch environment
*LaunchControllerApi* | [**get_jobs1**](src/client/generated/docs/LaunchControllerApi.md#get_jobs1) | **GET** /api/launch/{id}/job | Get launch jobs
*LaunchControllerApi* | [**get_member_stats**](src/client/generated/docs/LaunchControllerApi.md#get_member_stats) | **GET** /api/launch/{id}/memberstats | Get member stats widget data
*LaunchControllerApi* | [**get_muted_test_results**](src/client/generated/docs/LaunchControllerApi.md#get_muted_test_results) | **GET** /api/launch/{id}/muted | Get muted test results
*LaunchControllerApi* | [**get_progress**](src/client/generated/docs/LaunchControllerApi.md#get_progress) | **GET** /api/launch/{id}/progress | Get progress widget data
*LaunchControllerApi* | [**get_retries**](src/client/generated/docs/LaunchControllerApi.md#get_retries) | **GET** /api/launch/{id}/retries | Get retries widget data
*LaunchControllerApi* | [**get_statistic**](src/client/generated/docs/LaunchControllerApi.md#get_statistic) | **GET** /api/launch/{id}/statistic | Get launch statistic
*LaunchControllerApi* | [**get_testers**](src/client/generated/docs/LaunchControllerApi.md#get_testers) | **GET** /api/launch/{id}/tester | Get launch testers
*LaunchControllerApi* | [**get_unresolved_test_results**](src/client/generated/docs/LaunchControllerApi.md#get_unresolved_test_results) | **GET** /api/launch/{id}/unresolved | Get unresolved test results
*LaunchControllerApi* | [**get_variables**](src/client/generated/docs/LaunchControllerApi.md#get_variables) | **GET** /api/launch/{id}/variables | Get variables widget data
*LaunchControllerApi* | [**get_widget_tree**](src/client/generated/docs/LaunchControllerApi.md#get_widget_tree) | **GET** /api/launch/{id}/widget/tree | Get suites for tree data
*LaunchControllerApi* | [**merge**](src/client/generated/docs/LaunchControllerApi.md#merge) | **POST** /api/launch/merge | Merge launches
*LaunchControllerApi* | [**patch29**](src/client/generated/docs/LaunchControllerApi.md#patch29) | **PATCH** /api/launch/{id} | Patch launch
*LaunchControllerApi* | [**reopen**](src/client/generated/docs/LaunchControllerApi.md#reopen) | **POST** /api/launch/{id}/reopen | Reopen launch
*LaunchControllerApi* | [**suggest13**](src/client/generated/docs/LaunchControllerApi.md#suggest13) | **GET** /api/launch/suggest | Suggest for launches
*LaunchControllerApi* | [**suggest_jobs**](src/client/generated/docs/LaunchControllerApi.md#suggest_jobs) | **GET** /api/launch/{id}/job/suggest | Suggest launch jobs
*LaunchSearchControllerApi* | [**search2**](src/client/generated/docs/LaunchSearchControllerApi.md#search2) | **GET** /api/launch/__search | Find all launches by given AQL
*LaunchSearchControllerApi* | [**validate_query2**](src/client/generated/docs/LaunchSearchControllerApi.md#validate_query2) | **GET** /api/launch/query/validate | Find all launches by given AQL
*ProjectControllerApi* | [**calculate_stats**](src/client/generated/docs/ProjectControllerApi.md#calculate_stats) | **GET** /api/project/{id}/stats | Find project stats by id
*ProjectControllerApi* | [**count_test_cases_in_projects**](src/client/generated/docs/ProjectControllerApi.md#count_test_cases_in_projects) | **GET** /api/project/count-test-cases | Count test cases in projects that use specified custom field
*ProjectControllerApi* | [**create25**](src/client/generated/docs/ProjectControllerApi.md#create25) | **POST** /api/project | Create a new project
*ProjectControllerApi* | [**delete23**](src/client/generated/docs/ProjectControllerApi.md#delete23) | **DELETE** /api/project/{id} | Delete project by id
*ProjectControllerApi* | [**find_all21**](src/client/generated/docs/ProjectControllerApi.md#find_all21) | **GET** /api/project | Find all projects
*ProjectControllerApi* | [**find_by_custom_field**](src/client/generated/docs/ProjectControllerApi.md#find_by_custom_field) | **GET** /api/project/customfield | Find projects that use/do not use specified custom field
*ProjectControllerApi* | [**find_one19**](src/client/generated/docs/ProjectControllerApi.md#find_one19) | **GET** /api/project/{id} | Find project by id
*ProjectControllerApi* | [**get_suggest**](src/client/generated/docs/ProjectControllerApi.md#get_suggest) | **GET** /api/project/suggest | Suggest projects
*ProjectControllerApi* | [**patch25**](src/client/generated/docs/ProjectControllerApi.md#patch25) | **PATCH** /api/project/{id} | Patch project
*ProjectControllerApi* | [**set_favorite**](src/client/generated/docs/ProjectControllerApi.md#set_favorite) | **POST** /api/project/{id}/favorite | Mark project as favorite
*SharedStepAttachmentControllerApi* | [**create21**](src/client/generated/docs/SharedStepAttachmentControllerApi.md#create21) | **POST** /api/sharedstep/attachment | Upload new shared step attachments
*SharedStepAttachmentControllerApi* | [**delete19**](src/client/generated/docs/SharedStepAttachmentControllerApi.md#delete19) | **DELETE** /api/sharedstep/attachment/{id} | Delete shared step attachment
*SharedStepAttachmentControllerApi* | [**find_all17**](src/client/generated/docs/SharedStepAttachmentControllerApi.md#find_all17) | **GET** /api/sharedstep/attachment | Find attachments for shared step
*SharedStepAttachmentControllerApi* | [**patch19**](src/client/generated/docs/SharedStepAttachmentControllerApi.md#patch19) | **PATCH** /api/sharedstep/attachment/{id} | Patch shared step attachment
*SharedStepAttachmentControllerApi* | [**read_content3**](src/client/generated/docs/SharedStepAttachmentControllerApi.md#read_content3) | **GET** /api/sharedstep/attachment/{id}/content | Get attachment content by id
*SharedStepAttachmentControllerApi* | [**update_content3**](src/client/generated/docs/SharedStepAttachmentControllerApi.md#update_content3) | **PUT** /api/sharedstep/attachment/{id}/content | Update shared step attachment content
*SharedStepControllerApi* | [**archive**](src/client/generated/docs/SharedStepControllerApi.md#archive) | **POST** /api/sharedstep/{id}/archive | Archive ths shared step
*SharedStepControllerApi* | [**create19**](src/client/generated/docs/SharedStepControllerApi.md#create19) | **POST** /api/sharedstep | Create a new shared step
*SharedStepControllerApi* | [**delete18**](src/client/generated/docs/SharedStepControllerApi.md#delete18) | **DELETE** /api/sharedstep/{id} | Delete shared step by id
*SharedStepControllerApi* | [**find_all16**](src/client/generated/docs/SharedStepControllerApi.md#find_all16) | **GET** /api/sharedstep | Find all shared steps for specified project
*SharedStepControllerApi* | [**find_one15**](src/client/generated/docs/SharedStepControllerApi.md#find_one15) | **GET** /api/sharedstep/{id} | Find shared step by id
*SharedStepControllerApi* | [**patch18**](src/client/generated/docs/SharedStepControllerApi.md#patch18) | **PATCH** /api/sharedstep/{id} | Patch a specified shared step
*SharedStepControllerApi* | [**unarchive**](src/client/generated/docs/SharedStepControllerApi.md#unarchive) | **POST** /api/sharedstep/{id}/unarchive | Unarchive ths shared step
*SharedStepScenarioControllerApi* | [**copy**](src/client/generated/docs/SharedStepScenarioControllerApi.md#copy) | **POST** /api/sharedstep/step/{id}/copy | Copy scenario step
*SharedStepScenarioControllerApi* | [**create20**](src/client/generated/docs/SharedStepScenarioControllerApi.md#create20) | **POST** /api/sharedstep/step | Create scenario step
*SharedStepScenarioControllerApi* | [**delete_by_id2**](src/client/generated/docs/SharedStepScenarioControllerApi.md#delete_by_id2) | **DELETE** /api/sharedstep/step/{id} | Delete a specified scenario step
*SharedStepScenarioControllerApi* | [**delete_scenario1**](src/client/generated/docs/SharedStepScenarioControllerApi.md#delete_scenario1) | **DELETE** /api/sharedstep/{id}/scenario | Delete scenario for test case
*SharedStepScenarioControllerApi* | [**find_one40**](src/client/generated/docs/SharedStepScenarioControllerApi.md#find_one40) | **GET** /api/sharedstep/{id}/step | Get scenario for shared step
*SharedStepScenarioControllerApi* | [**move2**](src/client/generated/docs/SharedStepScenarioControllerApi.md#move2) | **POST** /api/sharedstep/step/{id}/move | Move scenario step
*SharedStepScenarioControllerApi* | [**patch_by_id1**](src/client/generated/docs/SharedStepScenarioControllerApi.md#patch_by_id1) | **PATCH** /api/sharedstep/step/{id} | Patch a specified scenario step
*SharedStepScenarioControllerApi* | [**set_shared_step_scenario**](src/client/generated/docs/SharedStepScenarioControllerApi.md#set_shared_step_scenario) | **POST** /api/sharedstep/{id}/scenario | Set new scenario for ss
*SharedStepScenarioControllerApi* | [**usage**](src/client/generated/docs/SharedStepScenarioControllerApi.md#usage) | **GET** /api/sharedstep/{id}/usage | Get testcases with usage of shared step
*StatusControllerApi* | [**create18**](src/client/generated/docs/StatusControllerApi.md#create18) | **POST** /api/status | Create a new status
*StatusControllerApi* | [**delete17**](src/client/generated/docs/StatusControllerApi.md#delete17) | **DELETE** /api/status/{id} | Delete status by id
*StatusControllerApi* | [**find_all15**](src/client/generated/docs/StatusControllerApi.md#find_all15) | **GET** /api/status | Find all statuses
*StatusControllerApi* | [**find_one14**](src/client/generated/docs/StatusControllerApi.md#find_one14) | **GET** /api/status/{id} | Find status by id
*StatusControllerApi* | [**patch17**](src/client/generated/docs/StatusControllerApi.md#patch17) | **PATCH** /api/status/{id} | Patch status
*StatusControllerApi* | [**suggest8**](src/client/generated/docs/StatusControllerApi.md#suggest8) | **GET** /api/status/suggest | Suggest statuses
*TestCaseAttachmentControllerApi* | [**create16**](src/client/generated/docs/TestCaseAttachmentControllerApi.md#create16) | **POST** /api/testcase/attachment | Upload new test case attachments
*TestCaseAttachmentControllerApi* | [**delete15**](src/client/generated/docs/TestCaseAttachmentControllerApi.md#delete15) | **DELETE** /api/testcase/attachment/{id} | Delete test case attachment
*TestCaseAttachmentControllerApi* | [**find_all13**](src/client/generated/docs/TestCaseAttachmentControllerApi.md#find_all13) | **GET** /api/testcase/attachment | Find attachments for test case
*TestCaseAttachmentControllerApi* | [**patch15**](src/client/generated/docs/TestCaseAttachmentControllerApi.md#patch15) | **PATCH** /api/testcase/attachment/{id} | Patch test case attachment
*TestCaseAttachmentControllerApi* | [**read_content2**](src/client/generated/docs/TestCaseAttachmentControllerApi.md#read_content2) | **GET** /api/testcase/attachment/{id}/content | Get attachment content by id
*TestCaseAttachmentControllerApi* | [**update_content2**](src/client/generated/docs/TestCaseAttachmentControllerApi.md#update_content2) | **PUT** /api/testcase/attachment/{id}/content | Update test case attachment content
*TestCaseBulkControllerApi* | [**cfv_add1**](src/client/generated/docs/TestCaseBulkControllerApi.md#cfv_add1) | **POST** /api/testcase/bulk/cfv/add | Add custom field values for all test cases
*TestCaseBulkControllerApi* | [**cfv_remove1**](src/client/generated/docs/TestCaseBulkControllerApi.md#cfv_remove1) | **POST** /api/testcase/bulk/cfv/remove | Remove custom field values for all test cases
*TestCaseBulkControllerApi* | [**clone_all1**](src/client/generated/docs/TestCaseBulkControllerApi.md#clone_all1) | **POST** /api/testcase/bulk/clone | Clone test cases by ids
*TestCaseBulkControllerApi* | [**create_test_plan1**](src/client/generated/docs/TestCaseBulkControllerApi.md#create_test_plan1) | **POST** /api/testcase/bulk/testplan/create | Create test plan from selected test cases
*TestCaseBulkControllerApi* | [**delete_all1**](src/client/generated/docs/TestCaseBulkControllerApi.md#delete_all1) | **POST** /api/testcase/bulk/remove | Remove test cases by ids
*TestCaseBulkControllerApi* | [**drag_and_drop1**](src/client/generated/docs/TestCaseBulkControllerApi.md#drag_and_drop1) | **POST** /api/testcase/bulk/draganddrop | dragAndDrop test cases for trees
*TestCaseBulkControllerApi* | [**external_link_add1**](src/client/generated/docs/TestCaseBulkControllerApi.md#external_link_add1) | **POST** /api/testcase/bulk/externallink/add | Add external link for all test cases
*TestCaseBulkControllerApi* | [**issue_add1**](src/client/generated/docs/TestCaseBulkControllerApi.md#issue_add1) | **POST** /api/testcase/bulk/issue/add | Add issues for all test cases
*TestCaseBulkControllerApi* | [**issue_remove1**](src/client/generated/docs/TestCaseBulkControllerApi.md#issue_remove1) | **POST** /api/testcase/bulk/issue/remove | Remove issues for all test cases
*TestCaseBulkControllerApi* | [**layer_set1**](src/client/generated/docs/TestCaseBulkControllerApi.md#layer_set1) | **POST** /api/testcase/bulk/layer/set | Set specified layer for all test cases
*TestCaseBulkControllerApi* | [**member_add1**](src/client/generated/docs/TestCaseBulkControllerApi.md#member_add1) | **POST** /api/testcase/bulk/member/add | Add members for all test cases
*TestCaseBulkControllerApi* | [**member_remove1**](src/client/generated/docs/TestCaseBulkControllerApi.md#member_remove1) | **POST** /api/testcase/bulk/member/remove | Remove member for all test cases
*TestCaseBulkControllerApi* | [**move_all1**](src/client/generated/docs/TestCaseBulkControllerApi.md#move_all1) | **POST** /api/testcase/bulk/move | Move test cases to other project
*TestCaseBulkControllerApi* | [**mute_add1**](src/client/generated/docs/TestCaseBulkControllerApi.md#mute_add1) | **POST** /api/testcase/bulk/mute/add | Add mute for all test cases
*TestCaseBulkControllerApi* | [**run4**](src/client/generated/docs/TestCaseBulkControllerApi.md#run4) | **POST** /api/testcase/bulk/run | Run selected test cases in a new launch
*TestCaseBulkControllerApi* | [**run5**](src/client/generated/docs/TestCaseBulkControllerApi.md#run5) | **POST** /api/testcase/bulk/run/new | Run selected test cases in a new launch
*TestCaseBulkControllerApi* | [**run6**](src/client/generated/docs/TestCaseBulkControllerApi.md#run6) | **POST** /api/testcase/bulk/run/existing | Run selected test cases in an existing launch
*TestCaseBulkControllerApi* | [**status_set1**](src/client/generated/docs/TestCaseBulkControllerApi.md#status_set1) | **POST** /api/testcase/bulk/status/set | Set specified status for all test cases
*TestCaseBulkControllerApi* | [**tags_add2**](src/client/generated/docs/TestCaseBulkControllerApi.md#tags_add2) | **POST** /api/testcase/bulk/tag/add | Add tags for all test cases
*TestCaseBulkControllerApi* | [**tags_remove2**](src/client/generated/docs/TestCaseBulkControllerApi.md#tags_remove2) | **POST** /api/testcase/bulk/tag/remove | Remove tags for all test cases
*TestCaseControllerApi* | [**create13**](src/client/generated/docs/TestCaseControllerApi.md#create13) | **POST** /api/testcase | Create a new test case
*TestCaseControllerApi* | [**delete13**](src/client/generated/docs/TestCaseControllerApi.md#delete13) | **DELETE** /api/testcase/{id} | Delete test case by id
*TestCaseControllerApi* | [**detach_automation**](src/client/generated/docs/TestCaseControllerApi.md#detach_automation) | **POST** /api/testcase/{id}/detachautomation | Detach automation from test case
*TestCaseControllerApi* | [**find_all11**](src/client/generated/docs/TestCaseControllerApi.md#find_all11) | **GET** /api/testcase | Find all test cases for specified project
*TestCaseControllerApi* | [**find_all_deleted**](src/client/generated/docs/TestCaseControllerApi.md#find_all_deleted) | **GET** /api/testcase/deleted | Find all deleted test cases for given project
*TestCaseControllerApi* | [**find_all_muted**](src/client/generated/docs/TestCaseControllerApi.md#find_all_muted) | **GET** /api/testcase/muted | Find all muted test cases for given project
*TestCaseControllerApi* | [**find_history1**](src/client/generated/docs/TestCaseControllerApi.md#find_history1) | **GET** /api/testcase/{id}/history | Find run history for test case
*TestCaseControllerApi* | [**find_history2**](src/client/generated/docs/TestCaseControllerApi.md#find_history2) | **GET** /api/testcase/history | Find run history for test case
*TestCaseControllerApi* | [**find_one11**](src/client/generated/docs/TestCaseControllerApi.md#find_one11) | **GET** /api/testcase/{id} | Find test case by id
*TestCaseControllerApi* | [**find_workflow**](src/client/generated/docs/TestCaseControllerApi.md#find_workflow) | **GET** /api/testcase/{id}/workflow | Find workflow for test case
*TestCaseControllerApi* | [**patch13**](src/client/generated/docs/TestCaseControllerApi.md#patch13) | **PATCH** /api/testcase/{id} | 
*TestCaseControllerApi* | [**restore**](src/client/generated/docs/TestCaseControllerApi.md#restore) | **POST** /api/testcase/{id}/restore | Restore test case by id
*TestCaseControllerApi* | [**suggest6**](src/client/generated/docs/TestCaseControllerApi.md#suggest6) | **GET** /api/testcase/suggest | Find suggest for test case
*TestCaseCustomFieldControllerApi* | [**get_custom_fields_with_values2**](src/client/generated/docs/TestCaseCustomFieldControllerApi.md#get_custom_fields_with_values2) | **POST** /api/testcase/cfv | Find custom fields with values for test cases
*TestCaseCustomFieldControllerApi* | [**get_custom_fields_with_values3**](src/client/generated/docs/TestCaseCustomFieldControllerApi.md#get_custom_fields_with_values3) | **GET** /api/testcase/{testCaseId}/cfv | Find custom fields with values for test case
*TestCaseCustomFieldControllerApi* | [**update_cfvs_of_test_case**](src/client/generated/docs/TestCaseCustomFieldControllerApi.md#update_cfvs_of_test_case) | **PATCH** /api/testcase/{testCaseId}/cfv | Update custom field values of test case
*TestCaseOverviewControllerApi* | [**get_overview**](src/client/generated/docs/TestCaseOverviewControllerApi.md#get_overview) | **GET** /api/testcase/{testCaseId}/overview | Get test case overview
*TestCaseScenarioControllerApi* | [**create15**](src/client/generated/docs/TestCaseScenarioControllerApi.md#create15) | **POST** /api/testcase/step | Create scenario step
*TestCaseScenarioControllerApi* | [**delete_by_id1**](src/client/generated/docs/TestCaseScenarioControllerApi.md#delete_by_id1) | **DELETE** /api/testcase/step/{id} | Delete a specified scenario step
*TestCaseScenarioControllerApi* | [**delete_scenario**](src/client/generated/docs/TestCaseScenarioControllerApi.md#delete_scenario) | **DELETE** /api/testcase/{id}/scenario | Delete scenario for test case
*TestCaseScenarioControllerApi* | [**get_normalized_scenario**](src/client/generated/docs/TestCaseScenarioControllerApi.md#get_normalized_scenario) | **GET** /api/testcase/{id}/step | Get scenario for test case
*TestCaseScenarioControllerApi* | [**get_scenario**](src/client/generated/docs/TestCaseScenarioControllerApi.md#get_scenario) | **GET** /api/testcase/{id}/scenario | Find scenario for test case
*TestCaseScenarioControllerApi* | [**get_scenario_from_last_run**](src/client/generated/docs/TestCaseScenarioControllerApi.md#get_scenario_from_last_run) | **GET** /api/testcase/{id}/scenariofromrun | Find scenario for test case from last run
*TestCaseScenarioControllerApi* | [**migrate_scenario**](src/client/generated/docs/TestCaseScenarioControllerApi.md#migrate_scenario) | **POST** /api/testcase/{id}/migrate | Migrate scenario for test case
*TestCaseScenarioControllerApi* | [**move**](src/client/generated/docs/TestCaseScenarioControllerApi.md#move) | **POST** /api/testcase/step/{id}/move | Move scenario step
*TestCaseScenarioControllerApi* | [**move1**](src/client/generated/docs/TestCaseScenarioControllerApi.md#move1) | **POST** /api/testcase/step/{id}/copy | Copy scenario step
*TestCaseScenarioControllerApi* | [**patch_by_id**](src/client/generated/docs/TestCaseScenarioControllerApi.md#patch_by_id) | **PATCH** /api/testcase/step/{id} | Patch a specified scenario step
*TestCaseScenarioControllerApi* | [**set_test_case_scenario**](src/client/generated/docs/TestCaseScenarioControllerApi.md#set_test_case_scenario) | **POST** /api/testcase/{id}/scenario | Set new type scenario for test case
*TestCaseSearchControllerApi* | [**search1**](src/client/generated/docs/TestCaseSearchControllerApi.md#search1) | **GET** /api/testcase/__search | Find all test cases by given AQL
*TestCaseSearchControllerApi* | [**validate_query1**](src/client/generated/docs/TestCaseSearchControllerApi.md#validate_query1) | **GET** /api/testcase/query/validate | Find all test cases by given AQL
*TestCaseTagControllerApi* | [**get_tags**](src/client/generated/docs/TestCaseTagControllerApi.md#get_tags) | **GET** /api/testcase/{testCaseId}/tag | Find tags for test case
*TestCaseTagControllerApi* | [**set_tags**](src/client/generated/docs/TestCaseTagControllerApi.md#set_tags) | **POST** /api/testcase/{testCaseId}/tag | Set test tags for test case
*TestCaseTestPlanBulkControllerApi* | [**create_test_plan**](src/client/generated/docs/TestCaseTestPlanBulkControllerApi.md#create_test_plan) | **POST** /api/v2/test-case/bulk/test-plan/create | Create test plan from selected test cases
*TestCaseTreeBulkControllerV2Api* | [**drag_and_drop**](src/client/generated/docs/TestCaseTreeBulkControllerV2Api.md#drag_and_drop) | **POST** /api/v2/test-case/tree/bulk/drag-and-drop | dragAndDrop test cases for trees
*TestCaseTreeControllerV2Api* | [**add_group**](src/client/generated/docs/TestCaseTreeControllerV2Api.md#add_group) | **POST** /api/v2/project/{projectId}/test-case/tree/group | Add a new group to the specified tree
*TestCaseTreeControllerV2Api* | [**add_leaf**](src/client/generated/docs/TestCaseTreeControllerV2Api.md#add_leaf) | **POST** /api/v2/project/{projectId}/test-case/tree/leaf | Add a new leaf to the specified tree
*TestCaseTreeControllerV2Api* | [**delete_group**](src/client/generated/docs/TestCaseTreeControllerV2Api.md#delete_group) | **DELETE** /api/v2/project/{projectId}/test-case/tree/group/{groupId} | Delete the specified group
*TestCaseTreeControllerV2Api* | [**get_tree_node**](src/client/generated/docs/TestCaseTreeControllerV2Api.md#get_tree_node) | **GET** /api/v2/project/{projectId}/test-case/tree/tree-node | Get test cases as a tree structure (AQL)
*TestCaseTreeControllerV2Api* | [**rename_group**](src/client/generated/docs/TestCaseTreeControllerV2Api.md#rename_group) | **PUT** /api/v2/project/{projectId}/test-case/tree/group/{groupId}/name | Rename the specified group
*TestCaseTreeControllerV2Api* | [**rename_leaf**](src/client/generated/docs/TestCaseTreeControllerV2Api.md#rename_leaf) | **PUT** /api/v2/project/{projectId}/test-case/tree/leaf/{leafId}/name | Rename the specified leaf
*TestCaseTreeControllerV2Api* | [**suggest1**](src/client/generated/docs/TestCaseTreeControllerV2Api.md#suggest1) | **GET** /api/v2/project/{projectId}/test-case/tree/suggest | Tree groups suggest
*TestCaseTreeControllerV2Api* | [**upsert**](src/client/generated/docs/TestCaseTreeControllerV2Api.md#upsert) | **PUT** /api/v2/project/{projectId}/test-case/tree/group | Add a new group to the specified tree and return group if it exists
*TestLayerControllerApi* | [**create9**](src/client/generated/docs/TestLayerControllerApi.md#create9) | **POST** /api/testlayer | 
*TestLayerControllerApi* | [**delete9**](src/client/generated/docs/TestLayerControllerApi.md#delete9) | **DELETE** /api/testlayer/{id} | 
*TestLayerControllerApi* | [**find_all7**](src/client/generated/docs/TestLayerControllerApi.md#find_all7) | **GET** /api/testlayer | 
*TestLayerControllerApi* | [**find_one8**](src/client/generated/docs/TestLayerControllerApi.md#find_one8) | **GET** /api/testlayer/{id} | 
*TestLayerControllerApi* | [**patch9**](src/client/generated/docs/TestLayerControllerApi.md#patch9) | **PATCH** /api/testlayer/{id} | 
*TestLayerControllerApi* | [**suggest4**](src/client/generated/docs/TestLayerControllerApi.md#suggest4) | **GET** /api/testlayer/suggest | 
*TestLayerSchemaControllerApi* | [**create8**](src/client/generated/docs/TestLayerSchemaControllerApi.md#create8) | **POST** /api/testlayerschema | Create a new test layer schema
*TestLayerSchemaControllerApi* | [**delete8**](src/client/generated/docs/TestLayerSchemaControllerApi.md#delete8) | **DELETE** /api/testlayerschema/{id} | Delete test layer schema by id
*TestLayerSchemaControllerApi* | [**find_all6**](src/client/generated/docs/TestLayerSchemaControllerApi.md#find_all6) | **GET** /api/testlayerschema | Find all test layer schemas for given project
*TestLayerSchemaControllerApi* | [**find_one7**](src/client/generated/docs/TestLayerSchemaControllerApi.md#find_one7) | **GET** /api/testlayerschema/{id} | Find test layer schema by id
*TestLayerSchemaControllerApi* | [**patch8**](src/client/generated/docs/TestLayerSchemaControllerApi.md#patch8) | **PATCH** /api/testlayerschema/{id} | Patch test layer schema
*TestPlanControllerApi* | [**assign2**](src/client/generated/docs/TestPlanControllerApi.md#assign2) | **POST** /api/testplan/{id}/assign | Assign test plan test cases to user
*TestPlanControllerApi* | [**create7**](src/client/generated/docs/TestPlanControllerApi.md#create7) | **POST** /api/testplan | Create a new test plan
*TestPlanControllerApi* | [**delete7**](src/client/generated/docs/TestPlanControllerApi.md#delete7) | **DELETE** /api/testplan/{id} | Delete test plan by given id
*TestPlanControllerApi* | [**find_all_by_project**](src/client/generated/docs/TestPlanControllerApi.md#find_all_by_project) | **GET** /api/testplan | Find all test plans for given project
*TestPlanControllerApi* | [**find_one6**](src/client/generated/docs/TestPlanControllerApi.md#find_one6) | **GET** /api/testplan/{id} | Find test plan by id
*TestPlanControllerApi* | [**get_diff**](src/client/generated/docs/TestPlanControllerApi.md#get_diff) | **GET** /api/testplan/{id}/diff | Get test plan test cases changes
*TestPlanControllerApi* | [**get_groups2**](src/client/generated/docs/TestPlanControllerApi.md#get_groups2) | **GET** /api/testplan/{id}/tree/group | Find tree groups for node
*TestPlanControllerApi* | [**get_jobs**](src/client/generated/docs/TestPlanControllerApi.md#get_jobs) | **GET** /api/testplan/{id}/job | Get test plan jobs statistic
*TestPlanControllerApi* | [**get_leafs1**](src/client/generated/docs/TestPlanControllerApi.md#get_leafs1) | **GET** /api/testplan/{id}/tree/leaf | Find tree leafs for node
*TestPlanControllerApi* | [**get_members2**](src/client/generated/docs/TestPlanControllerApi.md#get_members2) | **GET** /api/testplan/{id}/member | Get test plan members statistic
*TestPlanControllerApi* | [**patch7**](src/client/generated/docs/TestPlanControllerApi.md#patch7) | **PATCH** /api/testplan/{id} | Patch test plan
*TestPlanControllerApi* | [**reset_jobs**](src/client/generated/docs/TestPlanControllerApi.md#reset_jobs) | **POST** /api/testplan/{id}/resetjob | Reset test plan
*TestPlanControllerApi* | [**run3**](src/client/generated/docs/TestPlanControllerApi.md#run3) | **POST** /api/testplan/{id}/run | Run test plan by given id
*TestPlanControllerApi* | [**set_job_parameters**](src/client/generated/docs/TestPlanControllerApi.md#set_job_parameters) | **POST** /api/testplan/{id}/jobparameter | Configure test plan job parameters
*TestPlanControllerApi* | [**suggest3**](src/client/generated/docs/TestPlanControllerApi.md#suggest3) | **GET** /api/testplan/suggest | Suggest for test plans
*TestPlanControllerApi* | [**sync**](src/client/generated/docs/TestPlanControllerApi.md#sync) | **POST** /api/testplan/{id}/sync | Sync test plan
*TreeControllerV2Api* | [**find_all48**](src/client/generated/docs/TreeControllerV2Api.md#find_all48) | **GET** /api/v2/tree | 
*TreeControllerV2Api* | [**find_one38**](src/client/generated/docs/TreeControllerV2Api.md#find_one38) | **GET** /api/v2/tree/{id} | 


## Documentation For Models

 - [AccessGroupBulkDto](src/client/generated/docs/AccessGroupBulkDto.md)
 - [AccessGroupCreateDto](src/client/generated/docs/AccessGroupCreateDto.md)
 - [AccessGroupDto](src/client/generated/docs/AccessGroupDto.md)
 - [AccessGroupPaDto](src/client/generated/docs/AccessGroupPaDto.md)
 - [AccessGroupPatchDto](src/client/generated/docs/AccessGroupPatchDto.md)
 - [AccessGroupProjectAccessDto](src/client/generated/docs/AccessGroupProjectAccessDto.md)
 - [AccessGroupProjectsAddDto](src/client/generated/docs/AccessGroupProjectsAddDto.md)
 - [AccessGroupUserDto](src/client/generated/docs/AccessGroupUserDto.md)
 - [AccessGroupUsersAddDto](src/client/generated/docs/AccessGroupUsersAddDto.md)
 - [AllowedRoleDto](src/client/generated/docs/AllowedRoleDto.md)
 - [AnalyticAutomationTrendDto](src/client/generated/docs/AnalyticAutomationTrendDto.md)
 - [AnalyticDto](src/client/generated/docs/AnalyticDto.md)
 - [AnalyticInterval](src/client/generated/docs/AnalyticInterval.md)
 - [AnalyticLaunchDurationHistogramDto](src/client/generated/docs/AnalyticLaunchDurationHistogramDto.md)
 - [AnalyticMuteTrendDto](src/client/generated/docs/AnalyticMuteTrendDto.md)
 - [AnalyticTcAutomationCountDto](src/client/generated/docs/AnalyticTcAutomationCountDto.md)
 - [AnalyticTcStatusCountDto](src/client/generated/docs/AnalyticTcStatusCountDto.md)
 - [AnalyticTrByStatusTrendDto](src/client/generated/docs/AnalyticTrByStatusTrendDto.md)
 - [AqlValidateResponseDto](src/client/generated/docs/AqlValidateResponseDto.md)
 - [AssignRequestDto](src/client/generated/docs/AssignRequestDto.md)
 - [AsyncJobDto](src/client/generated/docs/AsyncJobDto.md)
 - [AsyncJobStatusDto](src/client/generated/docs/AsyncJobStatusDto.md)
 - [AsyncJobStepDto](src/client/generated/docs/AsyncJobStepDto.md)
 - [AsyncJobStepStatusDto](src/client/generated/docs/AsyncJobStepStatusDto.md)
 - [AsyncJobWithStepsDto](src/client/generated/docs/AsyncJobWithStepsDto.md)
 - [AttachmentRow](src/client/generated/docs/AttachmentRow.md)
 - [AttachmentStepDto](src/client/generated/docs/AttachmentStepDto.md)
 - [Attrs](src/client/generated/docs/Attrs.md)
 - [AuditActionTypeDto](src/client/generated/docs/AuditActionTypeDto.md)
 - [BlobStorageStats](src/client/generated/docs/BlobStorageStats.md)
 - [BlobStorageUpdateStats](src/client/generated/docs/BlobStorageUpdateStats.md)
 - [BodyStepDto](src/client/generated/docs/BodyStepDto.md)
 - [BoldMark](src/client/generated/docs/BoldMark.md)
 - [BusinessMetricDto](src/client/generated/docs/BusinessMetricDto.md)
 - [CategoryCreateDto](src/client/generated/docs/CategoryCreateDto.md)
 - [CategoryDto](src/client/generated/docs/CategoryDto.md)
 - [CategoryMatcherCreateDto](src/client/generated/docs/CategoryMatcherCreateDto.md)
 - [CategoryMatcherDto](src/client/generated/docs/CategoryMatcherDto.md)
 - [CategoryMatcherPatchDto](src/client/generated/docs/CategoryMatcherPatchDto.md)
 - [CategoryPatchDto](src/client/generated/docs/CategoryPatchDto.md)
 - [CfvMergeToExistingGlobalValueDto](src/client/generated/docs/CfvMergeToExistingGlobalValueDto.md)
 - [CfvMergeToNewGlobalValueDto](src/client/generated/docs/CfvMergeToNewGlobalValueDto.md)
 - [Ci](src/client/generated/docs/Ci.md)
 - [CleanerSchemaCreateDto](src/client/generated/docs/CleanerSchemaCreateDto.md)
 - [CleanerSchemaDto](src/client/generated/docs/CleanerSchemaDto.md)
 - [CleanerSchemaPatchDto](src/client/generated/docs/CleanerSchemaPatchDto.md)
 - [CleanerSchemaTargetDto](src/client/generated/docs/CleanerSchemaTargetDto.md)
 - [CodeBlockDocumentNode](src/client/generated/docs/CodeBlockDocumentNode.md)
 - [CodeMark](src/client/generated/docs/CodeMark.md)
 - [CommentCreateDto](src/client/generated/docs/CommentCreateDto.md)
 - [CommentDto](src/client/generated/docs/CommentDto.md)
 - [CommentPatchDto](src/client/generated/docs/CommentPatchDto.md)
 - [CreateLaunchEvent](src/client/generated/docs/CreateLaunchEvent.md)
 - [CsvImportOptions](src/client/generated/docs/CsvImportOptions.md)
 - [CustomFieldBulkAddToProjectsDto](src/client/generated/docs/CustomFieldBulkAddToProjectsDto.md)
 - [CustomFieldBulkArchiveDto](src/client/generated/docs/CustomFieldBulkArchiveDto.md)
 - [CustomFieldCreateDto](src/client/generated/docs/CustomFieldCreateDto.md)
 - [CustomFieldDto](src/client/generated/docs/CustomFieldDto.md)
 - [CustomFieldExportFieldMapping](src/client/generated/docs/CustomFieldExportFieldMapping.md)
 - [CustomFieldImportFieldMapping](src/client/generated/docs/CustomFieldImportFieldMapping.md)
 - [CustomFieldMergeDto](src/client/generated/docs/CustomFieldMergeDto.md)
 - [CustomFieldPatchDto](src/client/generated/docs/CustomFieldPatchDto.md)
 - [CustomFieldProjectCountDto](src/client/generated/docs/CustomFieldProjectCountDto.md)
 - [CustomFieldProjectDto](src/client/generated/docs/CustomFieldProjectDto.md)
 - [CustomFieldProjectPatchDto](src/client/generated/docs/CustomFieldProjectPatchDto.md)
 - [CustomFieldProjectWithValuesDto](src/client/generated/docs/CustomFieldProjectWithValuesDto.md)
 - [CustomFieldRawDto](src/client/generated/docs/CustomFieldRawDto.md)
 - [CustomFieldSchemaCountDto](src/client/generated/docs/CustomFieldSchemaCountDto.md)
 - [CustomFieldSchemaCreateDto](src/client/generated/docs/CustomFieldSchemaCreateDto.md)
 - [CustomFieldSchemaDto](src/client/generated/docs/CustomFieldSchemaDto.md)
 - [CustomFieldSchemaPatchDto](src/client/generated/docs/CustomFieldSchemaPatchDto.md)
 - [CustomFieldValueBulkDeleteDto](src/client/generated/docs/CustomFieldValueBulkDeleteDto.md)
 - [CustomFieldValueBulkMergeDto](src/client/generated/docs/CustomFieldValueBulkMergeDto.md)
 - [CustomFieldValueDto](src/client/generated/docs/CustomFieldValueDto.md)
 - [CustomFieldValuePatchDto](src/client/generated/docs/CustomFieldValuePatchDto.md)
 - [CustomFieldValueProjectCreateDto](src/client/generated/docs/CustomFieldValueProjectCreateDto.md)
 - [CustomFieldValueProjectMergeByIdDto](src/client/generated/docs/CustomFieldValueProjectMergeByIdDto.md)
 - [CustomFieldValueProjectMergeByNameDto](src/client/generated/docs/CustomFieldValueProjectMergeByNameDto.md)
 - [CustomFieldValueProjectPatchDto](src/client/generated/docs/CustomFieldValueProjectPatchDto.md)
 - [CustomFieldValueProjectRenameDto](src/client/generated/docs/CustomFieldValueProjectRenameDto.md)
 - [CustomFieldValueWithCfDto](src/client/generated/docs/CustomFieldValueWithCfDto.md)
 - [CustomFieldValueWithTcCountDto](src/client/generated/docs/CustomFieldValueWithTcCountDto.md)
 - [CustomFieldWithValuesDto](src/client/generated/docs/CustomFieldWithValuesDto.md)
 - [DashboardCopyDto](src/client/generated/docs/DashboardCopyDto.md)
 - [DashboardCreateDto](src/client/generated/docs/DashboardCreateDto.md)
 - [DashboardDragAndDropDto](src/client/generated/docs/DashboardDragAndDropDto.md)
 - [DashboardDto](src/client/generated/docs/DashboardDto.md)
 - [DashboardOverviewDto](src/client/generated/docs/DashboardOverviewDto.md)
 - [DashboardPatchDto](src/client/generated/docs/DashboardPatchDto.md)
 - [DashboardUpdateDto](src/client/generated/docs/DashboardUpdateDto.md)
 - [DefaultCustomFieldValueDto](src/client/generated/docs/DefaultCustomFieldValueDto.md)
 - [DefaultTextMarkupDocument](src/client/generated/docs/DefaultTextMarkupDocument.md)
 - [DefaultTextMarkupDocumentAllOfContent](src/client/generated/docs/DefaultTextMarkupDocumentAllOfContent.md)
 - [DefaultWebhookSettings](src/client/generated/docs/DefaultWebhookSettings.md)
 - [DefaultWebhookSettingsAllOfSubjects](src/client/generated/docs/DefaultWebhookSettingsAllOfSubjects.md)
 - [DefectBulkDto](src/client/generated/docs/DefectBulkDto.md)
 - [DefectCountRowDto](src/client/generated/docs/DefectCountRowDto.md)
 - [DefectCreateDto](src/client/generated/docs/DefectCreateDto.md)
 - [DefectDto](src/client/generated/docs/DefectDto.md)
 - [DefectIssueLinkDto](src/client/generated/docs/DefectIssueLinkDto.md)
 - [DefectMatcherCreateDto](src/client/generated/docs/DefectMatcherCreateDto.md)
 - [DefectMatcherDto](src/client/generated/docs/DefectMatcherDto.md)
 - [DefectMatcherPatchDto](src/client/generated/docs/DefectMatcherPatchDto.md)
 - [DefectOverviewDto](src/client/generated/docs/DefectOverviewDto.md)
 - [DefectPatchDto](src/client/generated/docs/DefectPatchDto.md)
 - [DefectRowDto](src/client/generated/docs/DefectRowDto.md)
 - [DefectWebhook](src/client/generated/docs/DefectWebhook.md)
 - [DiffValueChangeBoolean](src/client/generated/docs/DiffValueChangeBoolean.md)
 - [DiffValueChangeLong](src/client/generated/docs/DiffValueChangeLong.md)
 - [DiffValueChangeSetLong](src/client/generated/docs/DiffValueChangeSetLong.md)
 - [DiffValueChangeString](src/client/generated/docs/DiffValueChangeString.md)
 - [DocumentNode](src/client/generated/docs/DocumentNode.md)
 - [EnvVarCreateDto](src/client/generated/docs/EnvVarCreateDto.md)
 - [EnvVarDto](src/client/generated/docs/EnvVarDto.md)
 - [EnvVarMergeDto](src/client/generated/docs/EnvVarMergeDto.md)
 - [EnvVarPatchDto](src/client/generated/docs/EnvVarPatchDto.md)
 - [EnvVarSchemaCreateDto](src/client/generated/docs/EnvVarSchemaCreateDto.md)
 - [EnvVarSchemaDto](src/client/generated/docs/EnvVarSchemaDto.md)
 - [EnvVarSchemaPatchDto](src/client/generated/docs/EnvVarSchemaPatchDto.md)
 - [EnvVarValueCreateDto](src/client/generated/docs/EnvVarValueCreateDto.md)
 - [EnvVarValueDto](src/client/generated/docs/EnvVarValueDto.md)
 - [EnvVarValuePatchDto](src/client/generated/docs/EnvVarValuePatchDto.md)
 - [EnvironmentSetDto](src/client/generated/docs/EnvironmentSetDto.md)
 - [EventType](src/client/generated/docs/EventType.md)
 - [EventTypeSettings](src/client/generated/docs/EventTypeSettings.md)
 - [ExampleExportFieldMapping](src/client/generated/docs/ExampleExportFieldMapping.md)
 - [ExpectedBodyStepDto](src/client/generated/docs/ExpectedBodyStepDto.md)
 - [ExportFieldMappingTestCaseExportField](src/client/generated/docs/ExportFieldMappingTestCaseExportField.md)
 - [ExportFieldMappingTestResultExportField](src/client/generated/docs/ExportFieldMappingTestResultExportField.md)
 - [ExportRequestDto](src/client/generated/docs/ExportRequestDto.md)
 - [ExportStatus](src/client/generated/docs/ExportStatus.md)
 - [ExportType](src/client/generated/docs/ExportType.md)
 - [ExtFormField](src/client/generated/docs/ExtFormField.md)
 - [ExtFormFieldCheckbox](src/client/generated/docs/ExtFormFieldCheckbox.md)
 - [ExtFormFieldComposite](src/client/generated/docs/ExtFormFieldComposite.md)
 - [ExtFormFieldExternalSelect](src/client/generated/docs/ExtFormFieldExternalSelect.md)
 - [ExtFormFieldFormChoice](src/client/generated/docs/ExtFormFieldFormChoice.md)
 - [ExtFormFieldFormChoiceOption](src/client/generated/docs/ExtFormFieldFormChoiceOption.md)
 - [ExtFormFieldList](src/client/generated/docs/ExtFormFieldList.md)
 - [ExtFormFieldNumber](src/client/generated/docs/ExtFormFieldNumber.md)
 - [ExtFormFieldOption](src/client/generated/docs/ExtFormFieldOption.md)
 - [ExtFormFieldPassword](src/client/generated/docs/ExtFormFieldPassword.md)
 - [ExtFormFieldSelect](src/client/generated/docs/ExtFormFieldSelect.md)
 - [ExtFormFieldSlider](src/client/generated/docs/ExtFormFieldSlider.md)
 - [ExtFormFieldText](src/client/generated/docs/ExtFormFieldText.md)
 - [ExtFormFieldTextarea](src/client/generated/docs/ExtFormFieldTextarea.md)
 - [ExtFormFieldUnknown](src/client/generated/docs/ExtFormFieldUnknown.md)
 - [ExtIssueLink](src/client/generated/docs/ExtIssueLink.md)
 - [ExtIssueType](src/client/generated/docs/ExtIssueType.md)
 - [ExtProject](src/client/generated/docs/ExtProject.md)
 - [ExtSelectValue](src/client/generated/docs/ExtSelectValue.md)
 - [ExternalLinkDto](src/client/generated/docs/ExternalLinkDto.md)
 - [ExternalRunResponseDto](src/client/generated/docs/ExternalRunResponseDto.md)
 - [ExternalRunStartRequestDto](src/client/generated/docs/ExternalRunStartRequestDto.md)
 - [ExternalRunStopRequestDto](src/client/generated/docs/ExternalRunStopRequestDto.md)
 - [FileUploadResponseDto](src/client/generated/docs/FileUploadResponseDto.md)
 - [FilterBaseSetDto](src/client/generated/docs/FilterBaseSetDto.md)
 - [FilterCreateDto](src/client/generated/docs/FilterCreateDto.md)
 - [FilterDto](src/client/generated/docs/FilterDto.md)
 - [FilterPatchDto](src/client/generated/docs/FilterPatchDto.md)
 - [FilterTypeDto](src/client/generated/docs/FilterTypeDto.md)
 - [FindAll29200Response](src/client/generated/docs/FindAll29200Response.md)
 - [GlobalPermissionsDto](src/client/generated/docs/GlobalPermissionsDto.md)
 - [GlobalSettingsDto](src/client/generated/docs/GlobalSettingsDto.md)
 - [GlobalSettingsProjectCreatePatchDto](src/client/generated/docs/GlobalSettingsProjectCreatePatchDto.md)
 - [GridPosDto](src/client/generated/docs/GridPosDto.md)
 - [GroupBy](src/client/generated/docs/GroupBy.md)
 - [GroupNodeContext](src/client/generated/docs/GroupNodeContext.md)
 - [IdAndNameOnlyDto](src/client/generated/docs/IdAndNameOnlyDto.md)
 - [IdOnlyDto](src/client/generated/docs/IdOnlyDto.md)
 - [ImportRequestDto](src/client/generated/docs/ImportRequestDto.md)
 - [ImportRequestInfoDto](src/client/generated/docs/ImportRequestInfoDto.md)
 - [ImportRequestStateDto](src/client/generated/docs/ImportRequestStateDto.md)
 - [ImportRequestTypeDto](src/client/generated/docs/ImportRequestTypeDto.md)
 - [IntegrationCreateDto](src/client/generated/docs/IntegrationCreateDto.md)
 - [IntegrationDto](src/client/generated/docs/IntegrationDto.md)
 - [IntegrationExportCreateDto](src/client/generated/docs/IntegrationExportCreateDto.md)
 - [IntegrationExportDto](src/client/generated/docs/IntegrationExportDto.md)
 - [IntegrationExportPatchDto](src/client/generated/docs/IntegrationExportPatchDto.md)
 - [IntegrationFieldsFormDto](src/client/generated/docs/IntegrationFieldsFormDto.md)
 - [IntegrationFieldsFormDtoDefaultProjectFieldsInner](src/client/generated/docs/IntegrationFieldsFormDtoDefaultProjectFieldsInner.md)
 - [IntegrationInfoDto](src/client/generated/docs/IntegrationInfoDto.md)
 - [IntegrationLinksFixedDto](src/client/generated/docs/IntegrationLinksFixedDto.md)
 - [IntegrationOperationTypeDto](src/client/generated/docs/IntegrationOperationTypeDto.md)
 - [IntegrationPatchDto](src/client/generated/docs/IntegrationPatchDto.md)
 - [IntegrationRoutineTypeDto](src/client/generated/docs/IntegrationRoutineTypeDto.md)
 - [IntegrationTypeDto](src/client/generated/docs/IntegrationTypeDto.md)
 - [IntegrationValidateDto](src/client/generated/docs/IntegrationValidateDto.md)
 - [IntegrationWebhookCreateDto](src/client/generated/docs/IntegrationWebhookCreateDto.md)
 - [IntegrationWebhookDto](src/client/generated/docs/IntegrationWebhookDto.md)
 - [IntegrationWebhookLogDto](src/client/generated/docs/IntegrationWebhookLogDto.md)
 - [IntegrationWebhookPatchDto](src/client/generated/docs/IntegrationWebhookPatchDto.md)
 - [IntegrationWebhookTokenDto](src/client/generated/docs/IntegrationWebhookTokenDto.md)
 - [IssueCreateDto](src/client/generated/docs/IssueCreateDto.md)
 - [IssueDto](src/client/generated/docs/IssueDto.md)
 - [IssueImportFieldMapping](src/client/generated/docs/IssueImportFieldMapping.md)
 - [IssueIntegrationExportFieldMapping](src/client/generated/docs/IssueIntegrationExportFieldMapping.md)
 - [IssuePatchDto](src/client/generated/docs/IssuePatchDto.md)
 - [IssueSchemaCreateDto](src/client/generated/docs/IssueSchemaCreateDto.md)
 - [IssueSchemaDto](src/client/generated/docs/IssueSchemaDto.md)
 - [IssueSchemaPatchDto](src/client/generated/docs/IssueSchemaPatchDto.md)
 - [IssueToCreateDto](src/client/generated/docs/IssueToCreateDto.md)
 - [ItalicMark](src/client/generated/docs/ItalicMark.md)
 - [Job](src/client/generated/docs/Job.md)
 - [JobCreateDto](src/client/generated/docs/JobCreateDto.md)
 - [JobDto](src/client/generated/docs/JobDto.md)
 - [JobInfoDto](src/client/generated/docs/JobInfoDto.md)
 - [JobMapping](src/client/generated/docs/JobMapping.md)
 - [JobParameterDto](src/client/generated/docs/JobParameterDto.md)
 - [JobPatchDto](src/client/generated/docs/JobPatchDto.md)
 - [JobRerunRequestDto](src/client/generated/docs/JobRerunRequestDto.md)
 - [JobRun](src/client/generated/docs/JobRun.md)
 - [JobRunDto](src/client/generated/docs/JobRunDto.md)
 - [JobRunRequestDto](src/client/generated/docs/JobRunRequestDto.md)
 - [JobRunStageDto](src/client/generated/docs/JobRunStageDto.md)
 - [JobRunStatusDto](src/client/generated/docs/JobRunStatusDto.md)
 - [JobRunUploadInfoDto](src/client/generated/docs/JobRunUploadInfoDto.md)
 - [JobTestCasesStatDto](src/client/generated/docs/JobTestCasesStatDto.md)
 - [Launch](src/client/generated/docs/Launch.md)
 - [LaunchCleanupRequest](src/client/generated/docs/LaunchCleanupRequest.md)
 - [LaunchCloseConfigDto](src/client/generated/docs/LaunchCloseConfigDto.md)
 - [LaunchCopyRqDto](src/client/generated/docs/LaunchCopyRqDto.md)
 - [LaunchCreateAndUploadDto](src/client/generated/docs/LaunchCreateAndUploadDto.md)
 - [LaunchCreateDto](src/client/generated/docs/LaunchCreateDto.md)
 - [LaunchDiffCell](src/client/generated/docs/LaunchDiffCell.md)
 - [LaunchDiffMode](src/client/generated/docs/LaunchDiffMode.md)
 - [LaunchDiffRow](src/client/generated/docs/LaunchDiffRow.md)
 - [LaunchDiffStatusChangeDto](src/client/generated/docs/LaunchDiffStatusChangeDto.md)
 - [LaunchDiffTestResult](src/client/generated/docs/LaunchDiffTestResult.md)
 - [LaunchDiffTestResultDto](src/client/generated/docs/LaunchDiffTestResultDto.md)
 - [LaunchDto](src/client/generated/docs/LaunchDto.md)
 - [LaunchExistingUploadDto](src/client/generated/docs/LaunchExistingUploadDto.md)
 - [LaunchLiveDocConfigDto](src/client/generated/docs/LaunchLiveDocConfigDto.md)
 - [LaunchMemberStatsDto](src/client/generated/docs/LaunchMemberStatsDto.md)
 - [LaunchMergeDto](src/client/generated/docs/LaunchMergeDto.md)
 - [LaunchPatchDto](src/client/generated/docs/LaunchPatchDto.md)
 - [LaunchPdfOptions](src/client/generated/docs/LaunchPdfOptions.md)
 - [LaunchPdfPart](src/client/generated/docs/LaunchPdfPart.md)
 - [LaunchPdfStructure](src/client/generated/docs/LaunchPdfStructure.md)
 - [LaunchPreviewDto](src/client/generated/docs/LaunchPreviewDto.md)
 - [LaunchProgressDto](src/client/generated/docs/LaunchProgressDto.md)
 - [LaunchRowDto](src/client/generated/docs/LaunchRowDto.md)
 - [LaunchTagCreateDto](src/client/generated/docs/LaunchTagCreateDto.md)
 - [LaunchTagDto](src/client/generated/docs/LaunchTagDto.md)
 - [LaunchTagPatchDto](src/client/generated/docs/LaunchTagPatchDto.md)
 - [LaunchTestCasesAddDto](src/client/generated/docs/LaunchTestCasesAddDto.md)
 - [LaunchTestPlanAddDto](src/client/generated/docs/LaunchTestPlanAddDto.md)
 - [LaunchUploadResponseDto](src/client/generated/docs/LaunchUploadResponseDto.md)
 - [LaunchVariableDto](src/client/generated/docs/LaunchVariableDto.md)
 - [LaunchWebhook](src/client/generated/docs/LaunchWebhook.md)
 - [LineBreakParagraphNode](src/client/generated/docs/LineBreakParagraphNode.md)
 - [LinkExportFieldMapping](src/client/generated/docs/LinkExportFieldMapping.md)
 - [LinkImportFieldMapping](src/client/generated/docs/LinkImportFieldMapping.md)
 - [LinkMark](src/client/generated/docs/LinkMark.md)
 - [ListSelectionDto](src/client/generated/docs/ListSelectionDto.md)
 - [ManualSessionRequestDto](src/client/generated/docs/ManualSessionRequestDto.md)
 - [Matcher](src/client/generated/docs/Matcher.md)
 - [MemberCreateDto](src/client/generated/docs/MemberCreateDto.md)
 - [MemberDto](src/client/generated/docs/MemberDto.md)
 - [MemberPatchDto](src/client/generated/docs/MemberPatchDto.md)
 - [Metric](src/client/generated/docs/Metric.md)
 - [MfaGlobalSettingsDto](src/client/generated/docs/MfaGlobalSettingsDto.md)
 - [MfaGlobalSettingsPatchDto](src/client/generated/docs/MfaGlobalSettingsPatchDto.md)
 - [MultiValueExportFieldMapping](src/client/generated/docs/MultiValueExportFieldMapping.md)
 - [MultiValueImportFieldMapping](src/client/generated/docs/MultiValueImportFieldMapping.md)
 - [MultiValueMapStringString](src/client/generated/docs/MultiValueMapStringString.md)
 - [MuteCreateDto](src/client/generated/docs/MuteCreateDto.md)
 - [MuteDto](src/client/generated/docs/MuteDto.md)
 - [NameOnlyDto](src/client/generated/docs/NameOnlyDto.md)
 - [NodeType](src/client/generated/docs/NodeType.md)
 - [NormalizedScenarioDto](src/client/generated/docs/NormalizedScenarioDto.md)
 - [NormalizedScenarioDtoAttachmentsValue](src/client/generated/docs/NormalizedScenarioDtoAttachmentsValue.md)
 - [NormalizedScenarioStepDto](src/client/generated/docs/NormalizedScenarioStepDto.md)
 - [OrderedValueDtoString](src/client/generated/docs/OrderedValueDtoString.md)
 - [PageAccessGroupDto](src/client/generated/docs/PageAccessGroupDto.md)
 - [PageAccessGroupDtoSort](src/client/generated/docs/PageAccessGroupDtoSort.md)
 - [PageAccessGroupPaDto](src/client/generated/docs/PageAccessGroupPaDto.md)
 - [PageAccessGroupUserDto](src/client/generated/docs/PageAccessGroupUserDto.md)
 - [PageAsyncJobDto](src/client/generated/docs/PageAsyncJobDto.md)
 - [PageCategoryDto](src/client/generated/docs/PageCategoryDto.md)
 - [PageCategoryMatcherDto](src/client/generated/docs/PageCategoryMatcherDto.md)
 - [PageCleanerSchemaDto](src/client/generated/docs/PageCleanerSchemaDto.md)
 - [PageCommentDto](src/client/generated/docs/PageCommentDto.md)
 - [PageCustomFieldProjectDto](src/client/generated/docs/PageCustomFieldProjectDto.md)
 - [PageCustomFieldSchemaDto](src/client/generated/docs/PageCustomFieldSchemaDto.md)
 - [PageCustomFieldValueWithTcCountDto](src/client/generated/docs/PageCustomFieldValueWithTcCountDto.md)
 - [PageDashboardDto](src/client/generated/docs/PageDashboardDto.md)
 - [PageDefectCountRowDto](src/client/generated/docs/PageDefectCountRowDto.md)
 - [PageDefectDto](src/client/generated/docs/PageDefectDto.md)
 - [PageDefectMatcherDto](src/client/generated/docs/PageDefectMatcherDto.md)
 - [PageDefectRowDto](src/client/generated/docs/PageDefectRowDto.md)
 - [PageEnvVarSchemaDto](src/client/generated/docs/PageEnvVarSchemaDto.md)
 - [PageExportRequestDto](src/client/generated/docs/PageExportRequestDto.md)
 - [PageFilterDto](src/client/generated/docs/PageFilterDto.md)
 - [PageIdAndNameOnlyDto](src/client/generated/docs/PageIdAndNameOnlyDto.md)
 - [PageImportRequestDto](src/client/generated/docs/PageImportRequestDto.md)
 - [PageIntegrationDto](src/client/generated/docs/PageIntegrationDto.md)
 - [PageIntegrationExportDto](src/client/generated/docs/PageIntegrationExportDto.md)
 - [PageIntegrationInfoDto](src/client/generated/docs/PageIntegrationInfoDto.md)
 - [PageIntegrationWebhookDto](src/client/generated/docs/PageIntegrationWebhookDto.md)
 - [PageIntegrationWebhookLogDto](src/client/generated/docs/PageIntegrationWebhookLogDto.md)
 - [PageIssueDto](src/client/generated/docs/PageIssueDto.md)
 - [PageIssueSchemaDto](src/client/generated/docs/PageIssueSchemaDto.md)
 - [PageJobDto](src/client/generated/docs/PageJobDto.md)
 - [PageLaunchDiffRow](src/client/generated/docs/PageLaunchDiffRow.md)
 - [PageLaunchDto](src/client/generated/docs/PageLaunchDto.md)
 - [PageLaunchMemberStatsDto](src/client/generated/docs/PageLaunchMemberStatsDto.md)
 - [PageLaunchPreviewDto](src/client/generated/docs/PageLaunchPreviewDto.md)
 - [PageLaunchRowDto](src/client/generated/docs/PageLaunchRowDto.md)
 - [PageLaunchTagDto](src/client/generated/docs/PageLaunchTagDto.md)
 - [PageLaunchVariableDto](src/client/generated/docs/PageLaunchVariableDto.md)
 - [PageMemberDto](src/client/generated/docs/PageMemberDto.md)
 - [PageMuteDto](src/client/generated/docs/PageMuteDto.md)
 - [PagePermissionSetDto](src/client/generated/docs/PagePermissionSetDto.md)
 - [PageProjectCollaboratorAccessDto](src/client/generated/docs/PageProjectCollaboratorAccessDto.md)
 - [PageProjectCollaboratorDto](src/client/generated/docs/PageProjectCollaboratorDto.md)
 - [PageProjectCustomFieldDto](src/client/generated/docs/PageProjectCustomFieldDto.md)
 - [PageProjectDto](src/client/generated/docs/PageProjectDto.md)
 - [PageProjectGroupAccessDto](src/client/generated/docs/PageProjectGroupAccessDto.md)
 - [PageProjectIntegrationDto](src/client/generated/docs/PageProjectIntegrationDto.md)
 - [PageProjectSuggestDto](src/client/generated/docs/PageProjectSuggestDto.md)
 - [PageRoleSchemaDto](src/client/generated/docs/PageRoleSchemaDto.md)
 - [PageSharedStepAttachmentRowDto](src/client/generated/docs/PageSharedStepAttachmentRowDto.md)
 - [PageSharedStepDto](src/client/generated/docs/PageSharedStepDto.md)
 - [PageStatisticWidgetItem](src/client/generated/docs/PageStatisticWidgetItem.md)
 - [PageStatusDto](src/client/generated/docs/PageStatusDto.md)
 - [PageTemplateDto](src/client/generated/docs/PageTemplateDto.md)
 - [PageTestCaseAttachmentRowDto](src/client/generated/docs/PageTestCaseAttachmentRowDto.md)
 - [PageTestCaseAuditLogEntryDto](src/client/generated/docs/PageTestCaseAuditLogEntryDto.md)
 - [PageTestCaseDto](src/client/generated/docs/PageTestCaseDto.md)
 - [PageTestCaseExampleDto](src/client/generated/docs/PageTestCaseExampleDto.md)
 - [PageTestCaseFlatDto](src/client/generated/docs/PageTestCaseFlatDto.md)
 - [PageTestCaseRowDto](src/client/generated/docs/PageTestCaseRowDto.md)
 - [PageTestCaseTreeGroupDto](src/client/generated/docs/PageTestCaseTreeGroupDto.md)
 - [PageTestCaseTreeLeafDto](src/client/generated/docs/PageTestCaseTreeLeafDto.md)
 - [PageTestCaseTreeNodeDto](src/client/generated/docs/PageTestCaseTreeNodeDto.md)
 - [PageTestCaseTreeNodeDtoContentInner](src/client/generated/docs/PageTestCaseTreeNodeDtoContentInner.md)
 - [PageTestFixtureResultAttachmentRowDto](src/client/generated/docs/PageTestFixtureResultAttachmentRowDto.md)
 - [PageTestKeySchemaDto](src/client/generated/docs/PageTestKeySchemaDto.md)
 - [PageTestLayerDto](src/client/generated/docs/PageTestLayerDto.md)
 - [PageTestLayerSchemaDto](src/client/generated/docs/PageTestLayerSchemaDto.md)
 - [PageTestPlanDto](src/client/generated/docs/PageTestPlanDto.md)
 - [PageTestPlanRowDto](src/client/generated/docs/PageTestPlanRowDto.md)
 - [PageTestResultAttachmentRowDto](src/client/generated/docs/PageTestResultAttachmentRowDto.md)
 - [PageTestResultDefectMatchDto](src/client/generated/docs/PageTestResultDefectMatchDto.md)
 - [PageTestResultDto](src/client/generated/docs/PageTestResultDto.md)
 - [PageTestResultFlatDto](src/client/generated/docs/PageTestResultFlatDto.md)
 - [PageTestResultHistoryDto](src/client/generated/docs/PageTestResultHistoryDto.md)
 - [PageTestResultRetriesRowDto](src/client/generated/docs/PageTestResultRetriesRowDto.md)
 - [PageTestResultRowDto](src/client/generated/docs/PageTestResultRowDto.md)
 - [PageTestResultTreeGroupDto](src/client/generated/docs/PageTestResultTreeGroupDto.md)
 - [PageTestResultTreeLeafDto](src/client/generated/docs/PageTestResultTreeLeafDto.md)
 - [PageTestResultTreeNodeDto](src/client/generated/docs/PageTestResultTreeNodeDto.md)
 - [PageTestResultTreeNodeDtoContentInner](src/client/generated/docs/PageTestResultTreeNodeDtoContentInner.md)
 - [PageTreeDto](src/client/generated/docs/PageTreeDto.md)
 - [PageTreeDtoV2](src/client/generated/docs/PageTreeDtoV2.md)
 - [PageTreePathDto](src/client/generated/docs/PageTreePathDto.md)
 - [PageWebhookDto](src/client/generated/docs/PageWebhookDto.md)
 - [PageWidgetDto](src/client/generated/docs/PageWidgetDto.md)
 - [PageWorkflowDto](src/client/generated/docs/PageWorkflowDto.md)
 - [PageWorkflowSchemaDto](src/client/generated/docs/PageWorkflowSchemaDto.md)
 - [Pageable](src/client/generated/docs/Pageable.md)
 - [ParagraphDocumentNode](src/client/generated/docs/ParagraphDocumentNode.md)
 - [ParagraphDocumentNodeAllOfContent](src/client/generated/docs/ParagraphDocumentNodeAllOfContent.md)
 - [ParagraphNode](src/client/generated/docs/ParagraphNode.md)
 - [Parameter](src/client/generated/docs/Parameter.md)
 - [ParameterValueDto](src/client/generated/docs/ParameterValueDto.md)
 - [PermissionDto](src/client/generated/docs/PermissionDto.md)
 - [PermissionSetCreateDto](src/client/generated/docs/PermissionSetCreateDto.md)
 - [PermissionSetDto](src/client/generated/docs/PermissionSetDto.md)
 - [PermissionSetPatchDto](src/client/generated/docs/PermissionSetPatchDto.md)
 - [ProjectAccessCollaboratorAddDto](src/client/generated/docs/ProjectAccessCollaboratorAddDto.md)
 - [ProjectAccessGroupAddDto](src/client/generated/docs/ProjectAccessGroupAddDto.md)
 - [ProjectCategoryAddDto](src/client/generated/docs/ProjectCategoryAddDto.md)
 - [ProjectCategoryMatcherAddDto](src/client/generated/docs/ProjectCategoryMatcherAddDto.md)
 - [ProjectCategoryMatcherRemoveDto](src/client/generated/docs/ProjectCategoryMatcherRemoveDto.md)
 - [ProjectCategoryRemoveDto](src/client/generated/docs/ProjectCategoryRemoveDto.md)
 - [ProjectCollaboratorAccessDto](src/client/generated/docs/ProjectCollaboratorAccessDto.md)
 - [ProjectCollaboratorDto](src/client/generated/docs/ProjectCollaboratorDto.md)
 - [ProjectCreateDto](src/client/generated/docs/ProjectCreateDto.md)
 - [ProjectCustomFieldDto](src/client/generated/docs/ProjectCustomFieldDto.md)
 - [ProjectDto](src/client/generated/docs/ProjectDto.md)
 - [ProjectGroupAccessAddDto](src/client/generated/docs/ProjectGroupAccessAddDto.md)
 - [ProjectGroupAccessDto](src/client/generated/docs/ProjectGroupAccessDto.md)
 - [ProjectIntegrationCreateDto](src/client/generated/docs/ProjectIntegrationCreateDto.md)
 - [ProjectIntegrationDto](src/client/generated/docs/ProjectIntegrationDto.md)
 - [ProjectIntegrationFieldsFormDto](src/client/generated/docs/ProjectIntegrationFieldsFormDto.md)
 - [ProjectIntegrationPatchDto](src/client/generated/docs/ProjectIntegrationPatchDto.md)
 - [ProjectIntegrationValidateDto](src/client/generated/docs/ProjectIntegrationValidateDto.md)
 - [ProjectMetricDto](src/client/generated/docs/ProjectMetricDto.md)
 - [ProjectPatchDto](src/client/generated/docs/ProjectPatchDto.md)
 - [ProjectPropertyCreateDto](src/client/generated/docs/ProjectPropertyCreateDto.md)
 - [ProjectPropertyDto](src/client/generated/docs/ProjectPropertyDto.md)
 - [ProjectPropertyPatchDto](src/client/generated/docs/ProjectPropertyPatchDto.md)
 - [ProjectStatsDto](src/client/generated/docs/ProjectStatsDto.md)
 - [ProjectSuggestDto](src/client/generated/docs/ProjectSuggestDto.md)
 - [ProjectSyncRequest](src/client/generated/docs/ProjectSyncRequest.md)
 - [ProjectTestCaseCountDto](src/client/generated/docs/ProjectTestCaseCountDto.md)
 - [ResolveRequestV2Dto](src/client/generated/docs/ResolveRequestV2Dto.md)
 - [Retry](src/client/generated/docs/Retry.md)
 - [RoleCreateDto](src/client/generated/docs/RoleCreateDto.md)
 - [RoleDto](src/client/generated/docs/RoleDto.md)
 - [RoleExportFieldMapping](src/client/generated/docs/RoleExportFieldMapping.md)
 - [RoleImportFieldMapping](src/client/generated/docs/RoleImportFieldMapping.md)
 - [RolePatchDto](src/client/generated/docs/RolePatchDto.md)
 - [RoleSchemaCreateDto](src/client/generated/docs/RoleSchemaCreateDto.md)
 - [RoleSchemaDto](src/client/generated/docs/RoleSchemaDto.md)
 - [RoleSchemaPatchDto](src/client/generated/docs/RoleSchemaPatchDto.md)
 - [ScenarioExportFieldMapping](src/client/generated/docs/ScenarioExportFieldMapping.md)
 - [ScenarioStepCopyDto](src/client/generated/docs/ScenarioStepCopyDto.md)
 - [ScenarioStepCreateDto](src/client/generated/docs/ScenarioStepCreateDto.md)
 - [ScenarioStepCreatedResponseDto](src/client/generated/docs/ScenarioStepCreatedResponseDto.md)
 - [ScenarioStepDto](src/client/generated/docs/ScenarioStepDto.md)
 - [ScenarioStepMoveDto](src/client/generated/docs/ScenarioStepMoveDto.md)
 - [ScenarioStepPatchDto](src/client/generated/docs/ScenarioStepPatchDto.md)
 - [SessionVariable](src/client/generated/docs/SessionVariable.md)
 - [SharedStepAttachmentPatchDto](src/client/generated/docs/SharedStepAttachmentPatchDto.md)
 - [SharedStepAttachmentRowDto](src/client/generated/docs/SharedStepAttachmentRowDto.md)
 - [SharedStepCreateDto](src/client/generated/docs/SharedStepCreateDto.md)
 - [SharedStepDto](src/client/generated/docs/SharedStepDto.md)
 - [SharedStepPatchDto](src/client/generated/docs/SharedStepPatchDto.md)
 - [SharedStepScenarioDto](src/client/generated/docs/SharedStepScenarioDto.md)
 - [SharedStepScenarioDtoStepsInner](src/client/generated/docs/SharedStepScenarioDtoStepsInner.md)
 - [SharedStepStepDto](src/client/generated/docs/SharedStepStepDto.md)
 - [StatisticDto](src/client/generated/docs/StatisticDto.md)
 - [StatisticWidgetItem](src/client/generated/docs/StatisticWidgetItem.md)
 - [Status](src/client/generated/docs/Status.md)
 - [StatusCreateDto](src/client/generated/docs/StatusCreateDto.md)
 - [StatusDto](src/client/generated/docs/StatusDto.md)
 - [StatusPatchDto](src/client/generated/docs/StatusPatchDto.md)
 - [StrikeMark](src/client/generated/docs/StrikeMark.md)
 - [TagImportFieldMapping](src/client/generated/docs/TagImportFieldMapping.md)
 - [TemplateDto](src/client/generated/docs/TemplateDto.md)
 - [TemplateOverviewDto](src/client/generated/docs/TemplateOverviewDto.md)
 - [TestCaseAssociationDiff](src/client/generated/docs/TestCaseAssociationDiff.md)
 - [TestCaseAttachmentPatchDto](src/client/generated/docs/TestCaseAttachmentPatchDto.md)
 - [TestCaseAttachmentRowDto](src/client/generated/docs/TestCaseAttachmentRowDto.md)
 - [TestCaseAuditLogData](src/client/generated/docs/TestCaseAuditLogData.md)
 - [TestCaseAuditLogDataDiff](src/client/generated/docs/TestCaseAuditLogDataDiff.md)
 - [TestCaseAuditLogEntryDto](src/client/generated/docs/TestCaseAuditLogEntryDto.md)
 - [TestCaseBulkCfMoveStrategy](src/client/generated/docs/TestCaseBulkCfMoveStrategy.md)
 - [TestCaseBulkChangeProjectDtoV2](src/client/generated/docs/TestCaseBulkChangeProjectDtoV2.md)
 - [TestCaseBulkCloneDto](src/client/generated/docs/TestCaseBulkCloneDto.md)
 - [TestCaseBulkCloneDtoV2](src/client/generated/docs/TestCaseBulkCloneDtoV2.md)
 - [TestCaseBulkDragAndDropDto](src/client/generated/docs/TestCaseBulkDragAndDropDto.md)
 - [TestCaseBulkDragAndDropDtoV2](src/client/generated/docs/TestCaseBulkDragAndDropDtoV2.md)
 - [TestCaseBulkDto](src/client/generated/docs/TestCaseBulkDto.md)
 - [TestCaseBulkDtoV2](src/client/generated/docs/TestCaseBulkDtoV2.md)
 - [TestCaseBulkEntityIdsDto](src/client/generated/docs/TestCaseBulkEntityIdsDto.md)
 - [TestCaseBulkEntityIdsDtoV2](src/client/generated/docs/TestCaseBulkEntityIdsDtoV2.md)
 - [TestCaseBulkExportCsvOptions](src/client/generated/docs/TestCaseBulkExportCsvOptions.md)
 - [TestCaseBulkExportCsvOptionsMappingInner](src/client/generated/docs/TestCaseBulkExportCsvOptionsMappingInner.md)
 - [TestCaseBulkExportPdfOptions](src/client/generated/docs/TestCaseBulkExportPdfOptions.md)
 - [TestCaseBulkExternalLinkDto](src/client/generated/docs/TestCaseBulkExternalLinkDto.md)
 - [TestCaseBulkIssueDto](src/client/generated/docs/TestCaseBulkIssueDto.md)
 - [TestCaseBulkLayerDto](src/client/generated/docs/TestCaseBulkLayerDto.md)
 - [TestCaseBulkMemberDto](src/client/generated/docs/TestCaseBulkMemberDto.md)
 - [TestCaseBulkMuteDto](src/client/generated/docs/TestCaseBulkMuteDto.md)
 - [TestCaseBulkNewCfvDto](src/client/generated/docs/TestCaseBulkNewCfvDto.md)
 - [TestCaseBulkProjectChangeDto](src/client/generated/docs/TestCaseBulkProjectChangeDto.md)
 - [TestCaseBulkRunExistingLaunchDto](src/client/generated/docs/TestCaseBulkRunExistingLaunchDto.md)
 - [TestCaseBulkRunNewLaunchDto](src/client/generated/docs/TestCaseBulkRunNewLaunchDto.md)
 - [TestCaseBulkStatusDto](src/client/generated/docs/TestCaseBulkStatusDto.md)
 - [TestCaseBulkTagDto](src/client/generated/docs/TestCaseBulkTagDto.md)
 - [TestCaseBulkTestPlanCreateDto](src/client/generated/docs/TestCaseBulkTestPlanCreateDto.md)
 - [TestCaseCfBulkDeltaDtoV2](src/client/generated/docs/TestCaseCfBulkDeltaDtoV2.md)
 - [TestCaseCfvBulkAddDto](src/client/generated/docs/TestCaseCfvBulkAddDto.md)
 - [TestCaseCloneRqDto](src/client/generated/docs/TestCaseCloneRqDto.md)
 - [TestCaseCountDto](src/client/generated/docs/TestCaseCountDto.md)
 - [TestCaseCreateV2Dto](src/client/generated/docs/TestCaseCreateV2Dto.md)
 - [TestCaseCsvExportOptions](src/client/generated/docs/TestCaseCsvExportOptions.md)
 - [TestCaseCsvImportOptions](src/client/generated/docs/TestCaseCsvImportOptions.md)
 - [TestCaseCsvImportOptionsMappingInner](src/client/generated/docs/TestCaseCsvImportOptionsMappingInner.md)
 - [TestCaseCsvPreviewOptions](src/client/generated/docs/TestCaseCsvPreviewOptions.md)
 - [TestCaseDetachAutomationRqDto](src/client/generated/docs/TestCaseDetachAutomationRqDto.md)
 - [TestCaseDiff](src/client/generated/docs/TestCaseDiff.md)
 - [TestCaseDto](src/client/generated/docs/TestCaseDto.md)
 - [TestCaseExampleDto](src/client/generated/docs/TestCaseExampleDto.md)
 - [TestCaseExportField](src/client/generated/docs/TestCaseExportField.md)
 - [TestCaseExternalLinkBulkAddDto](src/client/generated/docs/TestCaseExternalLinkBulkAddDto.md)
 - [TestCaseFlatDto](src/client/generated/docs/TestCaseFlatDto.md)
 - [TestCaseFullTreeNodeDto](src/client/generated/docs/TestCaseFullTreeNodeDto.md)
 - [TestCaseImportDto](src/client/generated/docs/TestCaseImportDto.md)
 - [TestCaseImportField](src/client/generated/docs/TestCaseImportField.md)
 - [TestCaseImportMapping](src/client/generated/docs/TestCaseImportMapping.md)
 - [TestCaseInfo](src/client/generated/docs/TestCaseInfo.md)
 - [TestCaseIssueBulkAddDto](src/client/generated/docs/TestCaseIssueBulkAddDto.md)
 - [TestCaseLastResultDto](src/client/generated/docs/TestCaseLastResultDto.md)
 - [TestCaseLayerBulkSetDto](src/client/generated/docs/TestCaseLayerBulkSetDto.md)
 - [TestCaseLightTreeNodeDto](src/client/generated/docs/TestCaseLightTreeNodeDto.md)
 - [TestCaseMemberBulkAddDto](src/client/generated/docs/TestCaseMemberBulkAddDto.md)
 - [TestCaseMuteBulkAddDto](src/client/generated/docs/TestCaseMuteBulkAddDto.md)
 - [TestCaseOverviewDto](src/client/generated/docs/TestCaseOverviewDto.md)
 - [TestCaseParameterDto](src/client/generated/docs/TestCaseParameterDto.md)
 - [TestCaseParameterValues](src/client/generated/docs/TestCaseParameterValues.md)
 - [TestCasePatchV2Dto](src/client/generated/docs/TestCasePatchV2Dto.md)
 - [TestCasePdfOptions](src/client/generated/docs/TestCasePdfOptions.md)
 - [TestCasePdfPart](src/client/generated/docs/TestCasePdfPart.md)
 - [TestCaseRelationDto](src/client/generated/docs/TestCaseRelationDto.md)
 - [TestCaseRelationTypeDto](src/client/generated/docs/TestCaseRelationTypeDto.md)
 - [TestCaseRowDto](src/client/generated/docs/TestCaseRowDto.md)
 - [TestCaseRunBulkExistingLaunchDto](src/client/generated/docs/TestCaseRunBulkExistingLaunchDto.md)
 - [TestCaseRunBulkNewLaunchDto](src/client/generated/docs/TestCaseRunBulkNewLaunchDto.md)
 - [TestCaseRunByStats](src/client/generated/docs/TestCaseRunByStats.md)
 - [TestCaseRunStatsRequestDto](src/client/generated/docs/TestCaseRunStatsRequestDto.md)
 - [TestCaseScenarioDto](src/client/generated/docs/TestCaseScenarioDto.md)
 - [TestCaseScenarioStepDto](src/client/generated/docs/TestCaseScenarioStepDto.md)
 - [TestCaseScenarioV2Dto](src/client/generated/docs/TestCaseScenarioV2Dto.md)
 - [TestCaseSelectionDtoV2](src/client/generated/docs/TestCaseSelectionDtoV2.md)
 - [TestCaseStatusBulkSetDto](src/client/generated/docs/TestCaseStatusBulkSetDto.md)
 - [TestCaseStyle](src/client/generated/docs/TestCaseStyle.md)
 - [TestCaseSyncFromTo](src/client/generated/docs/TestCaseSyncFromTo.md)
 - [TestCaseSyncRqDto](src/client/generated/docs/TestCaseSyncRqDto.md)
 - [TestCaseTagBulkAddDto](src/client/generated/docs/TestCaseTagBulkAddDto.md)
 - [TestCaseTestPlanBulkCreateDto](src/client/generated/docs/TestCaseTestPlanBulkCreateDto.md)
 - [TestCaseTreeAllPathsDto](src/client/generated/docs/TestCaseTreeAllPathsDto.md)
 - [TestCaseTreeFilterCountDto](src/client/generated/docs/TestCaseTreeFilterCountDto.md)
 - [TestCaseTreeGroupAddDto](src/client/generated/docs/TestCaseTreeGroupAddDto.md)
 - [TestCaseTreeGroupDto](src/client/generated/docs/TestCaseTreeGroupDto.md)
 - [TestCaseTreeGroupRenameDto](src/client/generated/docs/TestCaseTreeGroupRenameDto.md)
 - [TestCaseTreeLeafAddDto](src/client/generated/docs/TestCaseTreeLeafAddDto.md)
 - [TestCaseTreeLeafDto](src/client/generated/docs/TestCaseTreeLeafDto.md)
 - [TestCaseTreeLeafDtoV2](src/client/generated/docs/TestCaseTreeLeafDtoV2.md)
 - [TestCaseTreeLeafRenameDto](src/client/generated/docs/TestCaseTreeLeafRenameDto.md)
 - [TestCaseTreeNodeDto](src/client/generated/docs/TestCaseTreeNodeDto.md)
 - [TestCaseTreeRunStatRequestDto](src/client/generated/docs/TestCaseTreeRunStatRequestDto.md)
 - [TestCaseTreeSelectionDto](src/client/generated/docs/TestCaseTreeSelectionDto.md)
 - [TestCaseTreeSelectionDtoV2](src/client/generated/docs/TestCaseTreeSelectionDtoV2.md)
 - [TestCaseType](src/client/generated/docs/TestCaseType.md)
 - [TestCaseUpdateFieldDto](src/client/generated/docs/TestCaseUpdateFieldDto.md)
 - [TestCaseUpdatePolicyDto](src/client/generated/docs/TestCaseUpdatePolicyDto.md)
 - [TestCaseUpdateSchemaCreateDto](src/client/generated/docs/TestCaseUpdateSchemaCreateDto.md)
 - [TestCaseUpdateSchemaDto](src/client/generated/docs/TestCaseUpdateSchemaDto.md)
 - [TestCaseUpdateSchemaPatchDto](src/client/generated/docs/TestCaseUpdateSchemaPatchDto.md)
 - [TestCaseVersionDto](src/client/generated/docs/TestCaseVersionDto.md)
 - [TestCaseVersionPatchDto](src/client/generated/docs/TestCaseVersionPatchDto.md)
 - [TestCaseVersionRqDto](src/client/generated/docs/TestCaseVersionRqDto.md)
 - [TestDurationCount](src/client/generated/docs/TestDurationCount.md)
 - [TestFixtureResultAttachmentPatchDto](src/client/generated/docs/TestFixtureResultAttachmentPatchDto.md)
 - [TestFixtureResultAttachmentRowDto](src/client/generated/docs/TestFixtureResultAttachmentRowDto.md)
 - [TestFixtureResultTypeDto](src/client/generated/docs/TestFixtureResultTypeDto.md)
 - [TestFixtureResultV2Dto](src/client/generated/docs/TestFixtureResultV2Dto.md)
 - [TestKeyDto](src/client/generated/docs/TestKeyDto.md)
 - [TestKeyImportFieldMapping](src/client/generated/docs/TestKeyImportFieldMapping.md)
 - [TestKeySchemaCreateDto](src/client/generated/docs/TestKeySchemaCreateDto.md)
 - [TestKeySchemaDto](src/client/generated/docs/TestKeySchemaDto.md)
 - [TestKeySchemaPatchDto](src/client/generated/docs/TestKeySchemaPatchDto.md)
 - [TestLayerCreateDto](src/client/generated/docs/TestLayerCreateDto.md)
 - [TestLayerDto](src/client/generated/docs/TestLayerDto.md)
 - [TestLayerPatchDto](src/client/generated/docs/TestLayerPatchDto.md)
 - [TestLayerSchemaCreateDto](src/client/generated/docs/TestLayerSchemaCreateDto.md)
 - [TestLayerSchemaDto](src/client/generated/docs/TestLayerSchemaDto.md)
 - [TestLayerSchemaPatchDto](src/client/generated/docs/TestLayerSchemaPatchDto.md)
 - [TestPlanAssignDto](src/client/generated/docs/TestPlanAssignDto.md)
 - [TestPlanCreateDto](src/client/generated/docs/TestPlanCreateDto.md)
 - [TestPlanDiffDto](src/client/generated/docs/TestPlanDiffDto.md)
 - [TestPlanDto](src/client/generated/docs/TestPlanDto.md)
 - [TestPlanJobParametersDto](src/client/generated/docs/TestPlanJobParametersDto.md)
 - [TestPlanJobStatDto](src/client/generated/docs/TestPlanJobStatDto.md)
 - [TestPlanMemberStatDto](src/client/generated/docs/TestPlanMemberStatDto.md)
 - [TestPlanPatchDto](src/client/generated/docs/TestPlanPatchDto.md)
 - [TestPlanRowDto](src/client/generated/docs/TestPlanRowDto.md)
 - [TestPlanRunRequestDto](src/client/generated/docs/TestPlanRunRequestDto.md)
 - [TestPlanTreeSelectionDto](src/client/generated/docs/TestPlanTreeSelectionDto.md)
 - [TestPlanWebhook](src/client/generated/docs/TestPlanWebhook.md)
 - [TestResultAttachmentPatchDto](src/client/generated/docs/TestResultAttachmentPatchDto.md)
 - [TestResultAttachmentRowDto](src/client/generated/docs/TestResultAttachmentRowDto.md)
 - [TestResultAttachmentStepDto](src/client/generated/docs/TestResultAttachmentStepDto.md)
 - [TestResultAttachmentStepDtoAllOfAttachment](src/client/generated/docs/TestResultAttachmentStepDtoAllOfAttachment.md)
 - [TestResultBodyStepDto](src/client/generated/docs/TestResultBodyStepDto.md)
 - [TestResultBulkAssignDto](src/client/generated/docs/TestResultBulkAssignDto.md)
 - [TestResultBulkDto](src/client/generated/docs/TestResultBulkDto.md)
 - [TestResultBulkEntityIdsDto](src/client/generated/docs/TestResultBulkEntityIdsDto.md)
 - [TestResultBulkMuteDto](src/client/generated/docs/TestResultBulkMuteDto.md)
 - [TestResultBulkRerunDto](src/client/generated/docs/TestResultBulkRerunDto.md)
 - [TestResultBulkResolveDto](src/client/generated/docs/TestResultBulkResolveDto.md)
 - [TestResultBulkTagDto](src/client/generated/docs/TestResultBulkTagDto.md)
 - [TestResultCreateV2Dto](src/client/generated/docs/TestResultCreateV2Dto.md)
 - [TestResultCsvExportOptions](src/client/generated/docs/TestResultCsvExportOptions.md)
 - [TestResultCsvExportOptionsMappingInner](src/client/generated/docs/TestResultCsvExportOptionsMappingInner.md)
 - [TestResultDefectMatchDto](src/client/generated/docs/TestResultDefectMatchDto.md)
 - [TestResultDefectMatcherDto](src/client/generated/docs/TestResultDefectMatcherDto.md)
 - [TestResultDto](src/client/generated/docs/TestResultDto.md)
 - [TestResultExpectedBodyStepDto](src/client/generated/docs/TestResultExpectedBodyStepDto.md)
 - [TestResultExportField](src/client/generated/docs/TestResultExportField.md)
 - [TestResultFlatDto](src/client/generated/docs/TestResultFlatDto.md)
 - [TestResultGroupNode](src/client/generated/docs/TestResultGroupNode.md)
 - [TestResultHistoryDto](src/client/generated/docs/TestResultHistoryDto.md)
 - [TestResultLeafNode](src/client/generated/docs/TestResultLeafNode.md)
 - [TestResultLinkDefectDto](src/client/generated/docs/TestResultLinkDefectDto.md)
 - [TestResultMuteReason](src/client/generated/docs/TestResultMuteReason.md)
 - [TestResultNewDefectDto](src/client/generated/docs/TestResultNewDefectDto.md)
 - [TestResultParameterDto](src/client/generated/docs/TestResultParameterDto.md)
 - [TestResultPatchDto](src/client/generated/docs/TestResultPatchDto.md)
 - [TestResultRerunDto](src/client/generated/docs/TestResultRerunDto.md)
 - [TestResultRetriesRowDto](src/client/generated/docs/TestResultRetriesRowDto.md)
 - [TestResultRowDto](src/client/generated/docs/TestResultRowDto.md)
 - [TestResultScenarioDto](src/client/generated/docs/TestResultScenarioDto.md)
 - [TestResultScenarioStepDto](src/client/generated/docs/TestResultScenarioStepDto.md)
 - [TestResultScenarioStepParameter](src/client/generated/docs/TestResultScenarioStepParameter.md)
 - [TestResultScenarioV2Dto](src/client/generated/docs/TestResultScenarioV2Dto.md)
 - [TestResultScenarioV2DtoStepsInner](src/client/generated/docs/TestResultScenarioV2DtoStepsInner.md)
 - [TestResultStatsDto](src/client/generated/docs/TestResultStatsDto.md)
 - [TestResultTree](src/client/generated/docs/TestResultTree.md)
 - [TestResultTreeFilterCountDto](src/client/generated/docs/TestResultTreeFilterCountDto.md)
 - [TestResultTreeGroupDto](src/client/generated/docs/TestResultTreeGroupDto.md)
 - [TestResultTreeGroupDtoV2](src/client/generated/docs/TestResultTreeGroupDtoV2.md)
 - [TestResultTreeLeafDto](src/client/generated/docs/TestResultTreeLeafDto.md)
 - [TestResultTreeLeafDtoV2](src/client/generated/docs/TestResultTreeLeafDtoV2.md)
 - [TestResultTreeNodeDto](src/client/generated/docs/TestResultTreeNodeDto.md)
 - [TestResultTreeSelectionDto](src/client/generated/docs/TestResultTreeSelectionDto.md)
 - [TestSessionResponseDto](src/client/generated/docs/TestSessionResponseDto.md)
 - [TestStatus](src/client/generated/docs/TestStatus.md)
 - [TestStatusCount](src/client/generated/docs/TestStatusCount.md)
 - [TestTagCreateDto](src/client/generated/docs/TestTagCreateDto.md)
 - [TestTagDto](src/client/generated/docs/TestTagDto.md)
 - [TestTagPatchDto](src/client/generated/docs/TestTagPatchDto.md)
 - [TextColorMark](src/client/generated/docs/TextColorMark.md)
 - [TextFillMark](src/client/generated/docs/TextFillMark.md)
 - [TextMark](src/client/generated/docs/TextMark.md)
 - [TextMarkupDocument](src/client/generated/docs/TextMarkupDocument.md)
 - [TextParagraphNode](src/client/generated/docs/TextParagraphNode.md)
 - [TextParagraphNodeMarksInner](src/client/generated/docs/TextParagraphNodeMarksInner.md)
 - [TrScenarioStepDto](src/client/generated/docs/TrScenarioStepDto.md)
 - [TreeCreateDto](src/client/generated/docs/TreeCreateDto.md)
 - [TreeCustomFieldProjectDto](src/client/generated/docs/TreeCustomFieldProjectDto.md)
 - [TreeDto](src/client/generated/docs/TreeDto.md)
 - [TreeDtoV2](src/client/generated/docs/TreeDtoV2.md)
 - [TreePatchDto](src/client/generated/docs/TreePatchDto.md)
 - [TreePathCreateDto](src/client/generated/docs/TreePathCreateDto.md)
 - [TreePathDto](src/client/generated/docs/TreePathDto.md)
 - [TreePathItemDto](src/client/generated/docs/TreePathItemDto.md)
 - [TreeSelectionDto](src/client/generated/docs/TreeSelectionDto.md)
 - [UnderlineMark](src/client/generated/docs/UnderlineMark.md)
 - [UploadAttachmentDto](src/client/generated/docs/UploadAttachmentDto.md)
 - [UploadFixturesResultsDto](src/client/generated/docs/UploadFixturesResultsDto.md)
 - [UploadLabelDto](src/client/generated/docs/UploadLabelDto.md)
 - [UploadLinkDto](src/client/generated/docs/UploadLinkDto.md)
 - [UploadParameterDto](src/client/generated/docs/UploadParameterDto.md)
 - [UploadResultsDto](src/client/generated/docs/UploadResultsDto.md)
 - [UploadResultsResponseDto](src/client/generated/docs/UploadResultsResponseDto.md)
 - [UploadTestCaseDto](src/client/generated/docs/UploadTestCaseDto.md)
 - [UploadTestFixtureResultDto](src/client/generated/docs/UploadTestFixtureResultDto.md)
 - [UploadTestFixtureResultDtoStepsInner](src/client/generated/docs/UploadTestFixtureResultDtoStepsInner.md)
 - [UploadTestFixtureType](src/client/generated/docs/UploadTestFixtureType.md)
 - [UploadTestResultAttachmentStepDto](src/client/generated/docs/UploadTestResultAttachmentStepDto.md)
 - [UploadTestResultBodyStepDto](src/client/generated/docs/UploadTestResultBodyStepDto.md)
 - [UploadTestResultDto](src/client/generated/docs/UploadTestResultDto.md)
 - [UploadTestResultExpectedBodyStepDto](src/client/generated/docs/UploadTestResultExpectedBodyStepDto.md)
 - [UploadTestResultStepDto](src/client/generated/docs/UploadTestResultStepDto.md)
 - [UploadTestStatus](src/client/generated/docs/UploadTestStatus.md)
 - [WebhookCreateDto](src/client/generated/docs/WebhookCreateDto.md)
 - [WebhookDto](src/client/generated/docs/WebhookDto.md)
 - [WebhookPatchDto](src/client/generated/docs/WebhookPatchDto.md)
 - [WebhookSettings](src/client/generated/docs/WebhookSettings.md)
 - [WebhookSubject](src/client/generated/docs/WebhookSubject.md)
 - [WebhookValidateDto](src/client/generated/docs/WebhookValidateDto.md)
 - [WidgetCreateDto](src/client/generated/docs/WidgetCreateDto.md)
 - [WidgetCreateDtoOptions](src/client/generated/docs/WidgetCreateDtoOptions.md)
 - [WidgetDataDto](src/client/generated/docs/WidgetDataDto.md)
 - [WidgetDto](src/client/generated/docs/WidgetDto.md)
 - [WidgetOptions](src/client/generated/docs/WidgetOptions.md)
 - [WidgetOptionsAnalyticGraph](src/client/generated/docs/WidgetOptionsAnalyticGraph.md)
 - [WidgetOptionsHavingSettableAql](src/client/generated/docs/WidgetOptionsHavingSettableAql.md)
 - [WidgetOptionsLastLaunchPieChart](src/client/generated/docs/WidgetOptionsLastLaunchPieChart.md)
 - [WidgetOptionsLaunchList](src/client/generated/docs/WidgetOptionsLaunchList.md)
 - [WidgetOptionsLaunchTrend](src/client/generated/docs/WidgetOptionsLaunchTrend.md)
 - [WidgetOptionsMarkdown](src/client/generated/docs/WidgetOptionsMarkdown.md)
 - [WidgetOptionsStatisticTrend](src/client/generated/docs/WidgetOptionsStatisticTrend.md)
 - [WidgetOptionsTcPieChart](src/client/generated/docs/WidgetOptionsTcPieChart.md)
 - [WidgetOptionsTcTreeMap](src/client/generated/docs/WidgetOptionsTcTreeMap.md)
 - [WidgetOptionsTopTc](src/client/generated/docs/WidgetOptionsTopTc.md)
 - [WidgetOptionsTrend](src/client/generated/docs/WidgetOptionsTrend.md)
 - [WidgetOptionsTrendV2](src/client/generated/docs/WidgetOptionsTrendV2.md)
 - [WidgetPatchDto](src/client/generated/docs/WidgetPatchDto.md)
 - [WidgetTypeDto](src/client/generated/docs/WidgetTypeDto.md)
 - [WorkflowCreateDto](src/client/generated/docs/WorkflowCreateDto.md)
 - [WorkflowDto](src/client/generated/docs/WorkflowDto.md)
 - [WorkflowPatchDto](src/client/generated/docs/WorkflowPatchDto.md)
 - [WorkflowRowDto](src/client/generated/docs/WorkflowRowDto.md)
 - [WorkflowSchemaCreateDto](src/client/generated/docs/WorkflowSchemaCreateDto.md)
 - [WorkflowSchemaDto](src/client/generated/docs/WorkflowSchemaDto.md)
 - [WorkflowSchemaPatchDto](src/client/generated/docs/WorkflowSchemaPatchDto.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




